<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance_budget');

// 记录访问日志
record_log('访问预算与成本管理页面');

// 添加/编辑/删除预算处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加预算
    if ($_POST['action'] == 'add') {
        $department = isset($_POST['department']) ? trim($_POST['department']) : '';
        $year = isset($_POST['year']) ? intval($_POST['year']) : date('Y');
        $month = isset($_POST['month']) ? intval($_POST['month']) : date('n');
        $budget_amount = isset($_POST['budget_amount']) ? floatval($_POST['budget_amount']) : 0;
        $actual_amount = isset($_POST['actual_amount']) ? floatval($_POST['actual_amount']) : 0;
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;

        if (empty($department) || $budget_amount <= 0) {
            $error = '请填写完整预算信息！';
        } else {
            try {
                // 检查是否已存在相同部门、年月、类型的预算
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM finance_budgets WHERE department = ? AND year = ? AND month = ? AND type = ?");
                $stmt->execute([$department, $year, $month, $type]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该部门在所选时间段内已有相同类型的预算记录！';
                } else {
                    // 添加预算
                    $stmt = $pdo->prepare("INSERT INTO finance_budgets (department, year, month, budget_amount, actual_amount, type) VALUES (?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$department, $year, $month, $budget_amount, $actual_amount, $type]);

                    if ($result) {
                        record_log("添加预算：{$department} {$year}年{$month}月 " . ($type == 1 ? '收入' : '支出'));
                        $success = '预算添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: budget.php?success=add');
                        exit;
                    } else {
                        $error = '预算添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑预算
    elseif ($_POST['action'] == 'edit') {
        $budget_id = isset($_POST['budget_id']) ? intval($_POST['budget_id']) : 0;
        $department = isset($_POST['department']) ? trim($_POST['department']) : '';
        $year = isset($_POST['year']) ? intval($_POST['year']) : date('Y');
        $month = isset($_POST['month']) ? intval($_POST['month']) : date('n');
        $budget_amount = isset($_POST['budget_amount']) ? floatval($_POST['budget_amount']) : 0;
        $actual_amount = isset($_POST['actual_amount']) ? floatval($_POST['actual_amount']) : 0;
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;

        if ($budget_id <= 0 || empty($department) || $budget_amount <= 0) {
            $error = '请填写完整预算信息！';
        } else {
            try {
                // 检查是否已存在相同部门、年月、类型的预算（除当前记录外）
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM finance_budgets WHERE department = ? AND year = ? AND month = ? AND type = ? AND id != ?");
                $stmt->execute([$department, $year, $month, $type, $budget_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该部门在所选时间段内已有相同类型的预算记录！';
                } else {
                    // 更新预算信息
                    $stmt = $pdo->prepare("UPDATE finance_budgets SET department = ?, year = ?, month = ?, budget_amount = ?, actual_amount = ?, type = ? WHERE id = ?");
                    $result = $stmt->execute([$department, $year, $month, $budget_amount, $actual_amount, $type, $budget_id]);

                    if ($result) {
                        record_log("编辑预算：{$department} {$year}年{$month}月 " . ($type == 1 ? '收入' : '支出'));
                        $success = '预算信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: budget.php?success=edit');
                        exit;
                    } else {
                        $error = '预算信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除预算
    elseif ($_POST['action'] == 'delete') {
        $budget_id = isset($_POST['budget_id']) ? intval($_POST['budget_id']) : 0;

        if ($budget_id <= 0) {
            $error = '无效的预算ID！';
        } else {
            try {
                // 获取预算信息，用于日志记录
                $stmt = $pdo->prepare("SELECT department, year, month, type FROM finance_budgets WHERE id = ?");
                $stmt->execute([$budget_id]);
                $budget = $stmt->fetch();

                if (!$budget) {
                    $error = '预算记录不存在！';
                } else {
                    // 删除预算
                    $stmt = $pdo->prepare("DELETE FROM finance_budgets WHERE id = ?");
                    $result = $stmt->execute([$budget_id]);

                    if ($result) {
                        record_log("删除预算：{$budget['department']} {$budget['year']}年{$budget['month']}月 " . ($budget['type'] == 1 ? '收入' : '支出'));
                        $success = '预算删除成功！';
                    } else {
                        $error = '预算删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 筛选条件
// 改成默认2023年
$filter_year = isset($_GET['year']) ? intval($_GET['year']) : 2023;
$filter_month = isset($_GET['month']) ? intval($_GET['month']) : 0; // 0表示全部月份
$filter_department = isset($_GET['department']) ? trim($_GET['department']) : '';
$filter_type = isset($_GET['type']) ? intval($_GET['type']) : 0; // 0表示全部类型

// 构建查询条件
$conditions = [];
$params = [];

if ($filter_year > 0) {
    $conditions[] = "year = ?";
    $params[] = $filter_year;
}

if ($filter_month > 0) {
    $conditions[] = "month = ?";
    $params[] = $filter_month;
}

if (!empty($filter_department)) {
    $conditions[] = "department = ?";
    $params[] = $filter_department;
}

if ($filter_type > 0) {
    $conditions[] = "type = ?";
    $params[] = $filter_type;
}

$where_clause = !empty($conditions) ? "WHERE " . implode(" AND ", $conditions) : "";

// 获取所有预算
try {
    $sql = "SELECT * FROM finance_budgets {$where_clause} ORDER BY year DESC, month DESC, department";

    if (!empty($params)) {
        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
    } else {
        $stmt = $pdo->query($sql);
    }

    $budgets = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取预算列表失败：' . $e->getMessage();
    $budgets = [];
}

// 获取所有部门（用于下拉列表）
try {
    $stmt = $pdo->query("SELECT DISTINCT department FROM finance_budgets ORDER BY department");
    $departments = $stmt->fetchAll(PDO::FETCH_COLUMN, 0);
} catch (PDOException $e) {
    $error = '获取部门列表失败：' . $e->getMessage();
    $departments = [];
}

// 计算汇总数据
$summary = [
    'income' => ['budget' => 0, 'actual' => 0],
    'expense' => ['budget' => 0, 'actual' => 0],
    'profit' => ['budget' => 0, 'actual' => 0]
];

foreach ($budgets as $budget) {
    if ($budget['type'] == 1) { // 收入
        $summary['income']['budget'] += $budget['budget_amount'];
        $summary['income']['actual'] += $budget['actual_amount'];
    } else { // 支出
        $summary['expense']['budget'] += $budget['budget_amount'];
        $summary['expense']['actual'] += $budget['actual_amount'];
    }
}

// 计算利润（收入-支出）
$summary['profit']['budget'] = $summary['income']['budget'] - $summary['expense']['budget'];
$summary['profit']['actual'] = $summary['income']['actual'] - $summary['expense']['actual'];

// 判断是否显示表单
$show_form = false;
$edit_budget = null;

// 编辑预算时显示表单并获取预算信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM finance_budgets WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_budget = $stmt->fetch();
        if (!$edit_budget) {
            $error = '预算记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取预算信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加预算时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '预算添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '预算信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>预算与成本管理</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 预算与成本管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="budget.php?action=add" class="btn btn-add">添加预算</a>
            </div>

            <!-- 筛选条件 -->
            <div class="filter-bar">
                <form method="get" action="" class="filter-form">
                    <div class="filter-item">
                        <label for="year">年份：</label>
                        <select id="year" name="year">
                            <?php for ($y = date('Y') + 1; $y >= date('Y') - 5; $y--): ?>
                                <option value="<?php echo $y; ?>" <?php echo $filter_year == $y ? 'selected' : ''; ?>><?php echo $y; ?>年</option>
                            <?php endfor; ?>
                        </select>
                    </div>
                    <div class="filter-item">
                        <label for="month">月份：</label>
                        <select id="month" name="month">
                            <option value="0" <?php echo $filter_month == 0 ? 'selected' : ''; ?>>全部</option>
                            <?php for ($m = 1; $m <= 12; $m++): ?>
                                <option value="<?php echo $m; ?>" <?php echo $filter_month == $m ? 'selected' : ''; ?>><?php echo $m; ?>月</option>
                            <?php endfor; ?>
                        </select>
                    </div>
                    <div class="filter-item">
                        <label for="department">部门：</label>
                        <select id="department" name="department">
                            <option value="" <?php echo $filter_department == '' ? 'selected' : ''; ?>>全部</option>
                            <?php foreach ($departments as $dept): ?>
                                <option value="<?php echo $dept; ?>" <?php echo $filter_department == $dept ? 'selected' : ''; ?>><?php echo $dept; ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="filter-item">
                        <label for="type">类型：</label>
                        <select id="type" name="type">
                            <option value="0" <?php echo $filter_type == 0 ? 'selected' : ''; ?>>全部</option>
                            <option value="1" <?php echo $filter_type == 1 ? 'selected' : ''; ?>>收入</option>
                            <option value="2" <?php echo $filter_type == 2 ? 'selected' : ''; ?>>支出</option>
                        </select>
                    </div>
                    <div class="filter-item">
                        <button type="submit" class="btn btn-secondary">筛选</button>
                        <a href="budget.php" class="btn btn-link">重置</a>
                    </div>
                </form>
            </div>

            <!-- 预算汇总信息 -->
            <div class="summary-container">
                <h3>预算汇总 (<?php echo $filter_year; ?>年<?php echo $filter_month > 0 ? $filter_month . '月' : ''; ?>)</h3>
                <div class="summary-cards">
                    <div class="summary-card">
                        <div class="card-title">总收入</div>
                        <div class="card-body">
                            <div class="amount">
                                <span class="label">预算：</span>
                                <span class="value"><?php echo number_format($summary['income']['budget'], 2); ?></span>
                            </div>
                            <div class="amount">
                                <span class="label">实际：</span>
                                <span class="value"><?php echo number_format($summary['income']['actual'], 2); ?></span>
                            </div>
                            <div class="amount">
                                <span class="label">完成率：</span>
                                <span class="value">
                                    <?php
                                    echo $summary['income']['budget'] > 0
                                        ? number_format(($summary['income']['actual'] / $summary['income']['budget']) * 100, 2) . '%'
                                        : '0.00%';
                                    ?>
                                </span>
                            </div>
                        </div>
                    </div>
                    <div class="summary-card">
                        <div class="card-title">总支出</div>
                        <div class="card-body">
                            <div class="amount">
                                <span class="label">预算：</span>
                                <span class="value"><?php echo number_format($summary['expense']['budget'], 2); ?></span>
                            </div>
                            <div class="amount">
                                <span class="label">实际：</span>
                                <span class="value"><?php echo number_format($summary['expense']['actual'], 2); ?></span>
                            </div>
                            <div class="amount">
                                <span class="label">完成率：</span>
                                <span class="value">
                                    <?php
                                    echo $summary['expense']['budget'] > 0
                                        ? number_format(($summary['expense']['actual'] / $summary['expense']['budget']) * 100, 2) . '%'
                                        : '0.00%';
                                    ?>
                                </span>
                            </div>
                        </div>
                    </div>
                    <div class="summary-card">
                        <div class="card-title">利润</div>
                        <div class="card-body">
                            <div class="amount">
                                <span class="label">预算：</span>
                                <span class="value"><?php echo number_format($summary['profit']['budget'], 2); ?></span>
                            </div>
                            <div class="amount">
                                <span class="label">实际：</span>
                                <span class="value"><?php echo number_format($summary['profit']['actual'], 2); ?></span>
                            </div>
                            <div class="amount">
                                <span class="label">完成率：</span>
                                <span class="value">
                                    <?php
                                    echo $summary['profit']['budget'] > 0
                                        ? number_format(($summary['profit']['actual'] / $summary['profit']['budget']) * 100, 2) . '%'
                                        : ($summary['profit']['budget'] < 0 && $summary['profit']['actual'] < 0
                                            ? number_format(($summary['profit']['actual'] / $summary['profit']['budget']) * 100, 2) . '%'
                                            : '0.00%');
                                    ?>
                                </span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <!-- 添加/编辑预算表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_budget ? '编辑预算' : '添加预算'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_budget ? 'edit' : 'add'; ?>">
                        <?php if ($edit_budget): ?>
                            <input type="hidden" name="budget_id" value="<?php echo $edit_budget['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="department">部门：</label>
                            <input type="text" id="department" name="department" value="<?php echo $edit_budget ? htmlspecialchars($edit_budget['department']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="year">年份：</label>
                            <select id="year" name="year" required>
                                <?php for ($y = date('Y') + 1; $y >= date('Y') - 5; $y--): ?>
                                    <option value="<?php echo $y; ?>" <?php echo ($edit_budget && $edit_budget['year'] == $y) ? 'selected' : ''; ?>><?php echo $y; ?>年</option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="month">月份：</label>
                            <select id="month" name="month" required>
                                <?php for ($m = 1; $m <= 12; $m++): ?>
                                    <option value="<?php echo $m; ?>" <?php echo ($edit_budget && $edit_budget['month'] == $m) ? 'selected' : ''; ?>><?php echo $m; ?>月</option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="type">类型：</label>
                            <select id="type" name="type" required>
                                <option value="1" <?php echo ($edit_budget && $edit_budget['type'] == 1) ? 'selected' : ''; ?>>收入</option>
                                <option value="2" <?php echo ($edit_budget && $edit_budget['type'] == 2) ? 'selected' : ''; ?>>支出</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="budget_amount">预算金额：</label>
                            <input type="number" id="budget_amount" name="budget_amount" step="0.01" min="0" value="<?php echo $edit_budget ? htmlspecialchars($edit_budget['budget_amount']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="actual_amount">实际金额：</label>
                            <input type="number" id="actual_amount" name="actual_amount" step="0.01" min="0" value="<?php echo $edit_budget ? htmlspecialchars($edit_budget['actual_amount']) : '0'; ?>">
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="budget.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 预算列表 -->
            <div class="table-container">
                <h3>预算列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>部门</th>
                            <th>年份</th>
                            <th>月份</th>
                            <th>类型</th>
                            <th>预算金额</th>
                            <th>实际金额</th>
                            <th>执行率</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($budgets)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无预算数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($budgets as $budget): ?>
                                <tr>
                                    <td><?php echo $budget['id']; ?></td>
                                    <td><?php echo htmlspecialchars($budget['department']); ?></td>
                                    <td><?php echo $budget['year']; ?></td>
                                    <td><?php echo $budget['month']; ?></td>
                                    <td>
                                        <?php
                                        if ($budget['type'] == 1) echo '<span class="status-active">收入</span>';
                                        else echo '<span class="status-inactive">支出</span>';
                                        ?>
                                    </td>
                                    <td><?php echo number_format($budget['budget_amount'], 2); ?></td>
                                    <td><?php echo number_format($budget['actual_amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($budget['budget_amount'] > 0) {
                                            $percent = ($budget['actual_amount'] / $budget['budget_amount']) * 100;
                                            if ($budget['type'] == 1) { // 收入
                                                if ($percent >= 100) echo '<span class="status-active">';
                                                else if ($percent >= 80) echo '<span class="status-pending">';
                                                else echo '<span class="status-inactive">';
                                            } else { // 支出
                                                if ($percent <= 100) echo '<span class="status-active">';
                                                else if ($percent <= 120) echo '<span class="status-pending">';
                                                else echo '<span class="status-inactive">';
                                            }
                                            echo number_format($percent, 2) . '%</span>';
                                        } else {
                                            echo '0.00%';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $budget['create_time']; ?></td>
                                    <td>
                                        <a href="budget.php?action=edit&id=<?php echo $budget['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="budget_id" value="<?php echo $budget['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除 <?php echo htmlspecialchars($budget['department']); ?> <?php echo $budget['year']; ?>年<?php echo $budget['month']; ?>月的<?php echo $budget['type'] == 1 ? '收入' : '支出'; ?>预算吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>