<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance_commission');

// 记录访问日志
record_log('访问佣金管理页面');

// 添加/编辑/删除佣金处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加佣金
    if ($_POST['action'] == 'add') {
        $user_id = isset($_POST['user_id']) ? intval($_POST['user_id']) : 0;
        $order_id = isset($_POST['order_id']) && $_POST['order_id'] > 0 ? intval($_POST['order_id']) : null;
        $contract_id = isset($_POST['contract_id']) && $_POST['contract_id'] > 0 ? intval($_POST['contract_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $rate = isset($_POST['rate']) ? floatval($_POST['rate']) : null;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $month = isset($_POST['month']) ? trim($_POST['month']) : date('Y-m');

        if ($user_id <= 0 || $amount <= 0 || (empty($order_id) && empty($contract_id))) {
            $error = '请填写完整佣金信息！';
        } else {
            try {
                // 添加佣金记录
                $stmt = $pdo->prepare("INSERT INTO finance_commissions (user_id, order_id, contract_id, amount, rate, status, month) VALUES (?, ?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$user_id, $order_id, $contract_id, $amount, $rate, $status, $month]);

                if ($result) {
                    record_log("添加佣金记录：用户ID {$user_id}，金额 {$amount}");
                    $success = '佣金记录添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: commission.php?success=add');
                    exit;
                } else {
                    $error = '佣金记录添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑佣金
    elseif ($_POST['action'] == 'edit') {
        $commission_id = isset($_POST['commission_id']) ? intval($_POST['commission_id']) : 0;
        $user_id = isset($_POST['user_id']) ? intval($_POST['user_id']) : 0;
        $order_id = isset($_POST['order_id']) && $_POST['order_id'] > 0 ? intval($_POST['order_id']) : null;
        $contract_id = isset($_POST['contract_id']) && $_POST['contract_id'] > 0 ? intval($_POST['contract_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $rate = isset($_POST['rate']) ? floatval($_POST['rate']) : null;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $month = isset($_POST['month']) ? trim($_POST['month']) : date('Y-m');

        if ($commission_id <= 0 || $user_id <= 0 || $amount <= 0 || (empty($order_id) && empty($contract_id))) {
            $error = '请填写完整佣金信息！';
        } else {
            try {
                // 更新佣金记录
                $stmt = $pdo->prepare("UPDATE finance_commissions SET user_id = ?, order_id = ?, contract_id = ?, amount = ?, rate = ?, status = ?, month = ? WHERE id = ?");
                $result = $stmt->execute([$user_id, $order_id, $contract_id, $amount, $rate, $status, $month, $commission_id]);

                if ($result) {
                    record_log("编辑佣金记录：ID {$commission_id}，金额 {$amount}");
                    $success = '佣金记录更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: commission.php?success=edit');
                    exit;
                } else {
                    $error = '佣金记录更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除佣金
    elseif ($_POST['action'] == 'delete') {
        $commission_id = isset($_POST['commission_id']) ? intval($_POST['commission_id']) : 0;

        if ($commission_id <= 0) {
            $error = '无效的佣金记录ID！';
        } else {
            try {
                // 获取佣金记录信息，用于日志记录
                $stmt = $pdo->prepare("SELECT amount, user_id FROM finance_commissions WHERE id = ?");
                $stmt->execute([$commission_id]);
                $commission = $stmt->fetch();

                if (!$commission) {
                    $error = '佣金记录不存在！';
                } else {
                    // 删除佣金记录
                    $stmt = $pdo->prepare("DELETE FROM finance_commissions WHERE id = ?");
                    $result = $stmt->execute([$commission_id]);

                    if ($result) {
                        record_log("删除佣金记录：ID {$commission_id}，用户ID {$commission['user_id']}，金额 {$commission['amount']}");
                        $success = '佣金记录删除成功！';
                    } else {
                        $error = '佣金记录删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 批量发放佣金
    elseif ($_POST['action'] == 'batch_pay') {
        $commission_ids = isset($_POST['commission_ids']) ? $_POST['commission_ids'] : [];

        if (empty($commission_ids)) {
            $error = '请选择要发放的佣金记录！';
        } else {
            try {
                $ids = implode(',', array_map('intval', $commission_ids));
                $stmt = $pdo->query("UPDATE finance_commissions SET status = 2 WHERE id IN ({$ids}) AND status = 1");

                if ($stmt->rowCount() > 0) {
                    record_log("批量发放佣金：{$stmt->rowCount()}条记录");
                    $success = '佣金批量发放成功！';
                } else {
                    $error = '佣金发放失败或无可发放记录！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有用户
try {
    $stmt = $pdo->query("SELECT id, username FROM sys_users WHERE status = 1 ORDER BY id");
    $users = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取用户列表失败：' . $e->getMessage();
    $users = [];
}

// 获取有效订单
try {
    $stmt = $pdo->query("SELECT id, order_no, amount FROM order_orders WHERE status IN (2, 3, 4) ORDER BY id DESC");
    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取订单列表失败：' . $e->getMessage();
    $orders = [];
}

// 获取有效合同
try {
    $stmt = $pdo->query("SELECT id, contract_no, amount FROM sales_contracts WHERE status = 3 ORDER BY id DESC");
    $contracts = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取合同列表失败：' . $e->getMessage();
    $contracts = [];
}

// 佣金筛选条件
$filter_user = isset($_GET['user_id']) ? intval($_GET['user_id']) : 0;
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : -1;
$filter_month = isset($_GET['month']) ? trim($_GET['month']) : '';

// 构建查询条件
$conditions = [];
$params = [];

if ($filter_user > 0) {
    $conditions[] = "c.user_id = ?";
    $params[] = $filter_user;
}

if ($filter_status >= 0) {
    $conditions[] = "c.status = ?";
    $params[] = $filter_status;
}

if (!empty($filter_month)) {
    $conditions[] = "c.month = ?";
    $params[] = $filter_month;
}

$where_clause = !empty($conditions) ? "WHERE " . implode(" AND ", $conditions) : "";

// 获取佣金记录
try {
    $sql = "SELECT c.*, u.username, o.order_no, s.contract_no 
            FROM finance_commissions c
            LEFT JOIN sys_users u ON c.user_id = u.id
            LEFT JOIN order_orders o ON c.order_id = o.id
            LEFT JOIN sales_contracts s ON c.contract_id = s.id
            {$where_clause}
            ORDER BY c.create_time DESC";

    if (!empty($params)) {
        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
    } else {
        $stmt = $pdo->query($sql);
    }

    $commissions = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取佣金列表失败：' . $e->getMessage();
    $commissions = [];
}

// 判断是否显示表单
$show_form = false;
$edit_commission = null;

// 编辑佣金时显示表单并获取佣金信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM finance_commissions WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_commission = $stmt->fetch();
        if (!$edit_commission) {
            $error = '佣金记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取佣金信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加佣金时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '佣金记录添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '佣金记录更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>佣金管理</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 佣金管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <button class="btn btn-primary" onclick="showAddForm()">添加佣金记录</button>
                <button class="btn btn-success" onclick="batchPayCommissions()">批量发放佣金</button>
            </div>

            <div class="filter-bar">
                <form method="get" action="" class="filter-form">
                    <div class="filter-item">
                        <label for="user_id">销售人员：</label>
                        <select id="user_id" name="user_id">
                            <option value="0">全部</option>
                            <?php foreach ($users as $user): ?>
                                <option value="<?php echo $user['id']; ?>" <?php echo $filter_user == $user['id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($user['username']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="filter-item">
                        <label for="status">状态：</label>
                        <select id="status" name="status">
                            <option value="-1">全部</option>
                            <option value="1" <?php echo $filter_status === 1 ? 'selected' : ''; ?>>待发放</option>
                            <option value="2" <?php echo $filter_status === 2 ? 'selected' : ''; ?>>已发放</option>
                        </select>
                    </div>
                    <div class="filter-item">
                        <label for="month">月份：</label>
                        <input type="month" id="month" name="month" value="<?php echo $filter_month; ?>">
                    </div>
                    <div class="filter-item">
                        <button type="submit" class="btn btn-secondary">筛选</button>
                        <a href="commission.php" class="btn btn-link">重置</a>
                    </div>
                </form>
            </div>

            <!-- 添加/编辑佣金表单 -->
            <?php if ($show_form): ?>
                <div id="commissionForm" class="form-container">
                    <h3><?php echo $edit_commission ? '编辑佣金记录' : '添加佣金记录'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_commission ? 'edit' : 'add'; ?>">
                        <?php if ($edit_commission): ?>
                            <input type="hidden" name="commission_id" value="<?php echo $edit_commission['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="user_id">销售人员：</label>
                            <select id="user_id" name="user_id" required>
                                <option value="">请选择销售人员</option>
                                <?php foreach ($users as $user): ?>
                                    <option value="<?php echo $user['id']; ?>" <?php echo ($edit_commission && $edit_commission['user_id'] == $user['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($user['username']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="order_id">关联订单：</label>
                            <select id="order_id" name="order_id">
                                <option value="">无关联订单</option>
                                <?php foreach ($orders as $order): ?>
                                    <option value="<?php echo $order['id']; ?>" <?php echo ($edit_commission && $edit_commission['order_id'] == $order['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($order['order_no']); ?> (<?php echo number_format($order['amount'], 2); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="contract_id">关联合同：</label>
                            <select id="contract_id" name="contract_id">
                                <option value="">无关联合同</option>
                                <?php foreach ($contracts as $contract): ?>
                                    <option value="<?php echo $contract['id']; ?>" <?php echo ($edit_commission && $edit_commission['contract_id'] == $contract['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($contract['contract_no']); ?> (<?php echo number_format($contract['amount'], 2); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">佣金金额：</label>
                            <input type="number" id="amount" name="amount" min="0" step="0.01" value="<?php echo $edit_commission ? htmlspecialchars($edit_commission['amount']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="rate">佣金比例(%)：</label>
                            <input type="number" id="rate" name="rate" min="0" max="100" step="0.01" value="<?php echo $edit_commission ? htmlspecialchars($edit_commission['rate']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_commission && $edit_commission['status'] == 1) ? 'selected' : ''; ?>>待发放</option>
                                <option value="2" <?php echo ($edit_commission && $edit_commission['status'] == 2) ? 'selected' : ''; ?>>已发放</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="month">佣金月份：</label>
                            <input type="month" id="month" name="month" value="<?php echo $edit_commission ? htmlspecialchars($edit_commission['month']) : date('Y-m'); ?>" required>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="commission.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <div id="commissionForm" class="form-container" style="display: none;">
                    <!-- 表单内容在 JavaScript 中动态填充 -->
                </div>
            <?php endif; ?>

            <!-- 佣金列表 -->
            <div class="table-container">
                <h3>佣金记录列表</h3>
                <form method="post" action="" id="batchForm">
                    <input type="hidden" name="action" value="batch_pay">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th><input type="checkbox" id="select-all" onclick="toggleSelectAll()"></th>
                                <th>ID</th>
                                <th>销售人员</th>
                                <th>关联订单</th>
                                <th>关联合同</th>
                                <th>佣金金额</th>
                                <th>佣金比例</th>
                                <th>状态</th>
                                <th>佣金月份</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($commissions)): ?>
                                <tr>
                                    <td colspan="11" class="text-center">暂无佣金记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($commissions as $commission): ?>
                                    <tr>
                                        <td>
                                            <?php if ($commission['status'] == 1): ?>
                                                <input type="checkbox" name="commission_ids[]" value="<?php echo $commission['id']; ?>" class="commission-checkbox">
                                            <?php endif; ?>
                                        </td>
                                        <td><?php echo $commission['id']; ?></td>
                                        <td><?php echo htmlspecialchars($commission['username']); ?></td>
                                        <td><?php echo $commission['order_no'] ? htmlspecialchars($commission['order_no']) : '-'; ?></td>
                                        <td><?php echo $commission['contract_no'] ? htmlspecialchars($commission['contract_no']) : '-'; ?></td>
                                        <td><?php echo number_format($commission['amount'], 2); ?></td>
                                        <td><?php echo $commission['rate'] ? $commission['rate'] . '%' : '-'; ?></td>
                                        <td>
                                            <?php
                                            if ($commission['status'] == 1) echo '<span class="status-pending">待发放</span>';
                                            elseif ($commission['status'] == 2) echo '<span class="status-active">已发放</span>';
                                            ?>
                                        </td>
                                        <td><?php echo $commission['month']; ?></td>
                                        <td><?php echo $commission['create_time']; ?></td>
                                        <td>
                                            <a href="commission.php?action=edit&id=<?php echo $commission['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                            <button type="button" class="btn btn-sm btn-danger" onclick="confirmDelete(<?php echo $commission['id']; ?>)">删除</button>
                                            <?php if ($commission['status'] == 1): ?>
                                                <button type="button" class="btn btn-sm btn-success" onclick="confirmPay(<?php echo $commission['id']; ?>)">发放</button>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </form>
            </div>

            <!-- 删除确认表单（隐藏） -->
            <form id="deleteForm" method="post" action="" style="display: none;">
                <input type="hidden" name="action" value="delete">
                <input type="hidden" name="commission_id" id="delete_commission_id" value="">
            </form>

            <!-- 发放确认表单（隐藏） -->
            <form id="payForm" method="post" action="" style="display: none;">
                <input type="hidden" name="action" value="batch_pay">
                <input type="hidden" name="commission_ids[]" id="pay_commission_id" value="">
            </form>
        </div>
    </div>

    <script>
        // 显示添加表单
        function showAddForm() {
            // 获取表单容器
            const formContainer = document.getElementById('commissionForm');

            // 动态创建表单内容
            formContainer.innerHTML = `
                <h3>添加佣金记录</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="add">

                    <div class="form-group">
                        <label for="user_id">销售人员：</label>
                        <select id="user_id" name="user_id" required>
                            <option value="">请选择销售人员</option>
                            <?php foreach ($users as $user): ?>
                                <option value="<?php echo $user['id']; ?>"><?php echo htmlspecialchars($user['username']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="order_id">关联订单：</label>
                        <select id="order_id" name="order_id">
                            <option value="">无关联订单</option>
                            <?php foreach ($orders as $order): ?>
                                <option value="<?php echo $order['id']; ?>"><?php echo htmlspecialchars($order['order_no']); ?> (<?php echo number_format($order['amount'], 2); ?>)</option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="contract_id">关联合同：</label>
                        <select id="contract_id" name="contract_id">
                            <option value="">无关联合同</option>
                            <?php foreach ($contracts as $contract): ?>
                                <option value="<?php echo $contract['id']; ?>"><?php echo htmlspecialchars($contract['contract_no']); ?> (<?php echo number_format($contract['amount'], 2); ?>)</option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="amount">佣金金额：</label>
                        <input type="number" id="amount" name="amount" min="0" step="0.01" required>
                    </div>

                    <div class="form-group">
                        <label for="rate">佣金比例(%)：</label>
                        <input type="number" id="rate" name="rate" min="0" max="100" step="0.01">
                    </div>

                    <div class="form-group">
                        <label for="status">状态：</label>
                        <select id="status" name="status">
                            <option value="1">待发放</option>
                            <option value="2">已发放</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="month">佣金月份：</label>
                        <input type="month" id="month" name="month" value="<?php echo date('Y-m'); ?>" required>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="hideAddForm()">取消</button>
                    </div>
                </form>
            `;

            // 显示表单
            formContainer.style.display = 'block';

            // 滚动到表单位置
            window.scrollTo({
                top: formContainer.offsetTop - 20,
                behavior: 'smooth'
            });
        }

        // 隐藏添加表单
        function hideAddForm() {
            document.getElementById('commissionForm').style.display = 'none';
        }

        // 确认删除
        function confirmDelete(id) {
            if (confirm('确定要删除这条佣金记录吗？此操作不可恢复！')) {
                document.getElementById('delete_commission_id').value = id;
                document.getElementById('deleteForm').submit();
            }
        }

        // 确认发放单条佣金
        function confirmPay(id) {
            if (confirm('确定要发放这条佣金吗？')) {
                document.getElementById('pay_commission_id').value = id;
                document.getElementById('payForm').submit();
            }
        }

        // 批量发放佣金
        function batchPayCommissions() {
            const checkboxes = document.querySelectorAll('.commission-checkbox:checked');
            if (checkboxes.length === 0) {
                alert('请选择要发放的佣金记录！');
                return;
            }

            if (confirm(`确定要发放选中的 ${checkboxes.length} 条佣金记录吗？`)) {
                document.getElementById('batchForm').submit();
            }
        }

        // 全选/取消全选
        function toggleSelectAll() {
            const checkboxes = document.querySelectorAll('.commission-checkbox');
            const selectAllCheckbox = document.getElementById('select-all');

            checkboxes.forEach(checkbox => {
                checkbox.checked = selectAllCheckbox.checked;
            });
        }

        // 订单和合同二选一
        document.addEventListener('DOMContentLoaded', function() {
            const orderSelect = document.getElementById('order_id');
            const contractSelect = document.getElementById('contract_id');

            if (orderSelect && contractSelect) {
                orderSelect.addEventListener('change', function() {
                    if (this.value) {
                        contractSelect.value = '';
                    }
                });

                contractSelect.addEventListener('change', function() {
                    if (this.value) {
                        orderSelect.value = '';
                    }
                });
            }
        });
    </script>
</body>

</html>