<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance');

// 记录访问日志
record_log('访问财务管理页面');

// 获取收款总额
try {
    $stmt = $pdo->query("SELECT SUM(amount) as total FROM finance_receipts WHERE status = 2");
    $total_receipt = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取收款数据失败：' . $e->getMessage();
    $total_receipt = ['total' => 0];
}

// 获取应收账款总额
try {
    $stmt = $pdo->query("SELECT SUM(amount - received_amount) as total FROM finance_receivables WHERE status != 3");
    $total_receivable = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取应收账款数据失败：' . $e->getMessage();
    $total_receivable = ['total' => 0];
}

// 获取未发放佣金总额
try {
    $stmt = $pdo->query("SELECT SUM(amount) as total FROM finance_commissions WHERE status = 1");
    $pending_commission = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取佣金数据失败：' . $e->getMessage();
    $pending_commission = ['total' => 0];
}

// 获取本月预算执行情况
try {
    $current_month = date('m');
    $current_year = date('Y');

    $stmt = $pdo->prepare("SELECT SUM(budget_amount) as budget, SUM(actual_amount) as actual 
                           FROM finance_budgets 
                           WHERE year = ? AND month = ? AND type = 1");
    $stmt->execute([$current_year, $current_month]);
    $income_budget = $stmt->fetch();

    $stmt = $pdo->prepare("SELECT SUM(budget_amount) as budget, SUM(actual_amount) as actual 
                           FROM finance_budgets 
                           WHERE year = ? AND month = ? AND type = 2");
    $stmt->execute([$current_year, $current_month]);
    $expense_budget = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取预算数据失败：' . $e->getMessage();
    $income_budget = ['budget' => 0, 'actual' => 0];
    $expense_budget = ['budget' => 0, 'actual' => 0];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>财务管理</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <h2>财务概览</h2>
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>已收款总额</h3>
                    <div class="number"><?php echo number_format($total_receipt['total'] ?: 0, 2); ?></div>
                    <div class="desc">已确认收款金额</div>
                </div>

                <div class="dashboard-card">
                    <h3>待收款总额</h3>
                    <div class="number"><?php echo number_format($total_receivable['total'] ?: 0, 2); ?></div>
                    <div class="desc">未收/部分收款金额</div>
                </div>

                <div class="dashboard-card">
                    <h3>待发放佣金</h3>
                    <div class="number"><?php echo number_format($pending_commission['total'] ?: 0, 2); ?></div>
                    <div class="desc">未发放的佣金总额</div>
                </div>

                <div class="dashboard-card">
                    <h3>预算执行率</h3>
                    <div class="number">
                        <?php
                        $income_rate = $income_budget['budget'] > 0 ? round(($income_budget['actual'] / $income_budget['budget']) * 100, 1) : 0;
                        $expense_rate = $expense_budget['budget'] > 0 ? round(($expense_budget['actual'] / $expense_budget['budget']) * 100, 1) : 0;
                        echo $income_rate . '% / ' . $expense_rate . '%';
                        ?>
                    </div>
                    <div class="desc">本月收入/支出执行率</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="receipt.php" class="function-link">
                    <h3>收款管理</h3>
                </a>
                <a href="payment.php" class="function-link">
                    <h3>付款审核</h3>
                </a>
                <a href="commission.php" class="function-link">
                    <h3>佣金管理</h3>
                </a>
                <a href="budget.php" class="function-link">
                    <h3>预算与成本管理</h3>
                </a>
                <a href="reconcile.php" class="function-link">
                    <h3>对账管理</h3>
                </a>
            </div>

            <h2>最近收款记录</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>收款编号</th>
                            <th>客户名称</th>
                            <th>收款金额</th>
                            <th>付款方式</th>
                            <th>付款时间</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT r.*, c.client_name
                                            FROM finance_receipts r
                                            JOIN crm_clients c ON r.client_id = c.id
                                            ORDER BY r.payment_time DESC LIMIT 5");
                            $receipts = $stmt->fetchAll();

                            if (empty($receipts)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无收款记录</td>
                                </tr>
                                <?php else:
                                foreach ($receipts as $receipt): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($receipt['receipt_no']); ?></td>
                                        <td><?php echo htmlspecialchars($receipt['client_name']); ?></td>
                                        <td><?php echo number_format($receipt['amount'], 2); ?></td>
                                        <td><?php echo htmlspecialchars($receipt['payment_method']); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($receipt['payment_time'])); ?></td>
                                        <td><?php echo $receipt['status'] == 1 ? '待确认' : '已确认'; ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="6" class="text-center">获取收款记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>

            <h2>本月待付款客户</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>客户名称</th>
                            <th>应收金额</th>
                            <th>已收金额</th>
                            <th>未收金额</th>
                            <th>到期日期</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $current_month_start = date('Y-m-01');
                            $current_month_end = date('Y-m-t');

                            $stmt = $pdo->prepare("SELECT r.*, c.client_name
                                            FROM finance_receivables r
                                            JOIN crm_clients c ON r.client_id = c.id
                                            WHERE r.due_date BETWEEN ? AND ?
                                            AND r.status != 3
                                            ORDER BY r.due_date ASC LIMIT 5");
                            $stmt->execute([$current_month_start, $current_month_end]);
                            $receivables = $stmt->fetchAll();

                            if (empty($receivables)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">本月暂无待付款记录</td>
                                </tr>
                                <?php else:
                                foreach ($receivables as $receivable): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($receivable['client_name']); ?></td>
                                        <td><?php echo number_format($receivable['amount'], 2); ?></td>
                                        <td><?php echo number_format($receivable['received_amount'], 2); ?></td>
                                        <td><?php echo number_format($receivable['amount'] - $receivable['received_amount'], 2); ?></td>
                                        <td><?php echo date('Y-m-d', strtotime($receivable['due_date'])); ?></td>
                                        <td>
                                            <?php
                                            if ($receivable['status'] == 1) echo '未收';
                                            elseif ($receivable['status'] == 2) echo '部分收款';
                                            else echo '已收';
                                            ?>
                                        </td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="6" class="text-center">获取应收账款记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>