<?php
require_once '../database_config.php';

// 检查会话中是否有成功消息
if (isset($_SESSION['success_message'])) {
    $success = $_SESSION['success_message'];
    unset($_SESSION['success_message']); // 删除会话中的消息，避免重复显示
}

// 检查用户是否有权限访问此页面
check_permission_or_die('order_invoice');

// 记录访问日志
record_log('访问发票管理页面');

// 获取筛选参数
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;

// 处理发票申请和状态更新
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 申请开票
    if ($_POST['action'] == 'apply') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $invoice_type = isset($_POST['invoice_type']) ? intval($_POST['invoice_type']) : 1;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $tax_no = isset($_POST['tax_no']) ? trim($_POST['tax_no']) : '';

        if ($order_id <= 0 || empty($title) || $amount <= 0) {
            $error = '请填写完整的发票申请信息！';
        } else {
            try {
                // 检查订单是否存在且已支付
                $stmt = $pdo->prepare("SELECT id, amount, status, order_no FROM order_orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $order = $stmt->fetch();

                if (!$order) {
                    $error = '订单不存在！';
                } elseif ($order['status'] < 2) { // 订单状态小于2表示未支付
                    $error = '只能为已支付的订单申请开票！';
                } else {
                    // 检查是否已经存在未取消的发票申请
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM order_invoices WHERE order_id = ? AND status != 4");
                    $stmt->execute([$order_id]);
                    $existing_invoice = $stmt->fetch();

                    if ($existing_invoice['count'] > 0) {
                        $error = '该订单已有未取消的发票申请！';
                    } else {
                        // 添加发票申请
                        $stmt = $pdo->prepare("
                            INSERT INTO order_invoices
                            (order_id, invoice_type, amount, title, tax_no, status)
                            VALUES (?, ?, ?, ?, ?, 1)
                        ");
                        $result = $stmt->execute([$order_id, $invoice_type, $amount, $title, $tax_no]);

                        if ($result) {
                            record_log("申请开票：订单 {$order['order_no']}，金额：{$amount}");
                            $_SESSION['success_message'] = '发票申请提交成功！';

                            // 重定向到列表页面
                            header('Location: invoice.php');
                            exit;
                        } else {
                            $error = '发票申请提交失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 更新发票状态
    elseif ($_POST['action'] == 'update_status') {
        $invoice_id = isset($_POST['invoice_id']) ? intval($_POST['invoice_id']) : 0;
        $new_status = isset($_POST['new_status']) ? intval($_POST['new_status']) : 0;
        $invoice_no = isset($_POST['invoice_no']) ? trim($_POST['invoice_no']) : '';
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($invoice_id <= 0 || $new_status < 1 || $new_status > 4) {
            $error = '参数无效！';
        } else {
            try {
                // 获取当前发票信息
                $stmt = $pdo->prepare("
                    SELECT i.*, o.order_no 
                    FROM order_invoices i
                    JOIN order_orders o ON i.order_id = o.id
                    WHERE i.id = ?
                ");
                $stmt->execute([$invoice_id]);
                $invoice = $stmt->fetch();

                if (!$invoice) {
                    $error = '发票不存在！';
                } else {
                    // 检查状态更新是否有效
                    $valid_update = false;
                    $current_status = $invoice['status'];

                    // 状态更新规则：
                    // 1(申请中) -> 2(已开票)或4(已取消)
                    // 2(已开票) -> 3(已寄出)或4(已取消)
                    // 3(已寄出) -> 不能更改
                    // 4(已取消) -> 不能更改

                    if ($current_status == 1 && ($new_status == 2 || $new_status == 4)) {
                        $valid_update = true;
                    } elseif ($current_status == 2 && ($new_status == 3 || $new_status == 4)) {
                        $valid_update = true;
                    } elseif ($current_status == $new_status) {
                        $error = '发票已经是该状态，无需更新！';
                    } else {
                        $error = '无效的状态更新！只能按照状态流程进行更新。';
                    }

                    if ($valid_update) {
                        // 添加所有需要更新的字段到$sql_parts
                        $sql_parts = ["status = ?"];
                        $params = [$new_status];

                        // 如果是更新为已开票状态，添加发票号码
                        if ($new_status == 2) {
                            $sql_parts[] = "invoice_no = ?";
                            $params[] = $invoice_no;
                        }

                        // 添加备注（如果有）
                        if (!empty($remark)) {
                            $sql_parts[] = "remark = ?";
                            $params[] = $remark;
                        }

                        // 构建完整SQL语句
                        $sql = "UPDATE order_invoices SET " . implode(", ", $sql_parts) . " WHERE id = ?";
                        $params[] = $invoice_id;

                        $stmt = $pdo->prepare($sql);
                        $result = $stmt->execute($params);

                        if ($result) {
                            // 获取状态文本
                            $status_text = '';
                            if ($new_status == 1) $status_text = '申请中';
                            elseif ($new_status == 2) $status_text = '已开票';
                            elseif ($new_status == 3) $status_text = '已寄出';
                            elseif ($new_status == 4) $status_text = '已取消';

                            record_log("更新发票状态：订单 {$invoice['order_no']}，新状态：{$status_text}");
                            $_SESSION['success_message'] = "发票状态已更新为：{$status_text}！";

                            // 重定向回发票页面
                            header('Location: invoice.php' . ($filter_status ? '?status=' . $filter_status : ''));
                            exit;
                        } else {
                            $error = '发票状态更新失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 状态筛选查询条件
$status_condition = '';
$status_params = [];
if ($filter_status > 0) {
    $status_condition = " WHERE i.status = ?";
    $status_params = [$filter_status];
}

// 获取所有发票
try {
    $sql = "
        SELECT i.*, o.order_no, o.client_id, c.client_name
        FROM order_invoices i
        JOIN order_orders o ON i.order_id = o.id
        JOIN crm_clients c ON o.client_id = c.id
        {$status_condition}
        ORDER BY i.create_time DESC
    ";

    $stmt = $pdo->prepare($sql);
    if (!empty($status_params)) {
        $stmt->execute($status_params);
    } else {
        $stmt->execute();
    }

    $invoices = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取发票列表失败：' . $e->getMessage();
    $invoices = [];
}

// 获取各状态发票数量
try {
    $stmt = $pdo->query("
        SELECT status, COUNT(*) as count 
        FROM order_invoices 
        GROUP BY status
    ");
    $status_counts = [];
    while ($row = $stmt->fetch()) {
        $status_counts[$row['status']] = $row['count'];
    }
} catch (PDOException $e) {
    $error = '获取发票状态统计失败：' . $e->getMessage();
    $status_counts = [];
}

// 获取总发票数
$total_invoices = array_sum($status_counts);

// 获取已支付但未申请发票的订单（用于申请开票）
try {
    $stmt = $pdo->query("
        SELECT o.*, c.client_name
        FROM order_orders o
        JOIN crm_clients c ON o.client_id = c.id
        WHERE o.status >= 2 AND o.status != 5
        AND NOT EXISTS (
            SELECT 1 FROM order_invoices i 
            WHERE i.order_id = o.id AND i.status != 4
        )
        ORDER BY o.create_time DESC
    ");
    $available_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取可申请开票订单失败：' . $e->getMessage();
    $available_orders = [];
}

// 判断是否显示申请开票表单
$show_apply_form = isset($_GET['action']) && $_GET['action'] == 'apply';

// 判断是否显示状态更新表单
$show_update_form = false;
$invoice_to_update = null;

// 显示状态更新表单
if (isset($_GET['action']) && $_GET['action'] == 'update' && isset($_GET['id'])) {
    $show_update_form = true;
    $invoice_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT i.*, o.order_no, c.client_name
            FROM order_invoices i
            JOIN order_orders o ON i.order_id = o.id
            JOIN crm_clients c ON o.client_id = c.id
            WHERE i.id = ?
        ");
        $stmt->execute([$invoice_id]);
        $invoice_to_update = $stmt->fetch();

        if (!$invoice_to_update) {
            $error = '发票不存在！';
            $show_update_form = false;
        } elseif ($invoice_to_update['status'] == 3 || $invoice_to_update['status'] == 4) {
            $error = '已寄出或已取消的发票不能再更新状态！';
            $show_update_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取发票信息失败：' . $e->getMessage();
        $show_update_form = false;
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>发票管理</h2>
            <div class="breadcrumb">
                <a href="index.php">订单管理</a> &gt; 发票管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 发票状态统计 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>全部发票</h3>
                    <div class="number"><?php echo $total_invoices; ?></div>
                    <div class="desc"><a href="invoice.php">查看全部</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>申请中</h3>
                    <div class="number"><?php echo isset($status_counts[1]) ? $status_counts[1] : 0; ?></div>
                    <div class="desc"><a href="invoice.php?status=1">筛选查看</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已开票</h3>
                    <div class="number"><?php echo isset($status_counts[2]) ? $status_counts[2] : 0; ?></div>
                    <div class="desc"><a href="invoice.php?status=2">筛选查看</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已寄出</h3>
                    <div class="number"><?php echo isset($status_counts[3]) ? $status_counts[3] : 0; ?></div>
                    <div class="desc"><a href="invoice.php?status=3">筛选查看</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已取消</h3>
                    <div class="number"><?php echo isset($status_counts[4]) ? $status_counts[4] : 0; ?></div>
                    <div class="desc"><a href="invoice.php?status=4">筛选查看</a></div>
                </div>
            </div>

            <div class="action-bar">
                <a href="invoice.php?action=apply" class="btn btn-add">申请开票</a>
            </div>

            <!-- 申请开票表单 -->
            <?php if ($show_apply_form): ?>
                <div class="form-container">
                    <h3>申请开票</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="apply">

                        <div class="form-group">
                            <label for="order_id">选择订单：</label>
                            <select id="order_id" name="order_id" required>
                                <option value="">请选择订单</option>
                                <?php foreach ($available_orders as $order): ?>
                                    <option value="<?php echo $order['id']; ?>" data-amount="<?php echo $order['amount']; ?>">
                                        <?php echo htmlspecialchars($order['order_no']); ?> -
                                        <?php echo htmlspecialchars($order['client_name']); ?> -
                                        <?php echo number_format($order['amount'], 2); ?>元
                                    </option>
                                <?php endforeach; ?>
                            </select>
                            <?php if (empty($available_orders)): ?>
                                <small class="text-danger">暂无可申请开票的订单</small>
                            <?php endif; ?>
                        </div>

                        <div class="form-group">
                            <label for="invoice_type">发票类型：</label>
                            <select id="invoice_type" name="invoice_type" required>
                                <option value="1">普通发票</option>
                                <option value="2">增值税专用发票</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">发票金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0" required>
                            <small>通常为订单金额</small>
                        </div>

                        <div class="form-group">
                            <label for="title">发票抬头：</label>
                            <input type="text" id="title" name="title" required>
                        </div>

                        <div class="form-group">
                            <label for="tax_no">税号：</label>
                            <input type="text" id="tax_no" name="tax_no">
                            <small>增值税专用发票必填</small>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">提交申请</button>
                            <a href="invoice.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 发票状态更新表单 -->
            <?php if ($show_update_form && $invoice_to_update): ?>
                <div class="form-container">
                    <h3>更新发票状态 - 订单编号: <?php echo htmlspecialchars($invoice_to_update['order_no']); ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="update_status">
                        <input type="hidden" name="invoice_id" value="<?php echo $invoice_to_update['id']; ?>">

                        <div class="form-group">
                            <label>客户名称：</label>
                            <div class="form-static"><?php echo htmlspecialchars($invoice_to_update['client_name']); ?></div>
                        </div>

                        <div class="form-group">
                            <label>发票抬头：</label>
                            <div class="form-static"><?php echo htmlspecialchars($invoice_to_update['title']); ?></div>
                        </div>

                        <div class="form-group">
                            <label>发票金额：</label>
                            <div class="form-static"><?php echo number_format($invoice_to_update['amount'], 2); ?>元</div>
                        </div>

                        <div class="form-group">
                            <label>当前状态：</label>
                            <div class="form-static">
                                <?php
                                if ($invoice_to_update['status'] == 1) echo '<span class="status-pending">申请中</span>';
                                elseif ($invoice_to_update['status'] == 2) echo '<span class="status-pending">已开票</span>';
                                ?>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="new_status">新状态：</label>
                            <select id="new_status" name="new_status" required>
                                <?php if ($invoice_to_update['status'] == 1): ?>
                                    <option value="2">已开票</option>
                                    <option value="4">已取消</option>
                                <?php elseif ($invoice_to_update['status'] == 2): ?>
                                    <option value="3">已寄出</option>
                                    <option value="4">已取消</option>
                                <?php endif; ?>
                            </select>
                        </div>

                        <?php if ($invoice_to_update['status'] == 1): ?>
                            <div class="form-group" id="invoice_no_group">
                                <label for="invoice_no">发票号码：</label>
                                <input type="text" id="invoice_no" name="invoice_no" required>
                                <small>标记为已开票时必填</small>
                            </div>
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="3" placeholder="可选，输入状态更新的原因或相关信息"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">更新状态</button>
                            <a href="invoice.php<?php echo $filter_status ? '?status=' . $filter_status : ''; ?>" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 发票列表 -->
            <div class="table-container">
                <h3>
                    <?php
                    if ($filter_status == 1) echo '申请中发票列表';
                    elseif ($filter_status == 2) echo '已开票发票列表';
                    elseif ($filter_status == 3) echo '已寄出发票列表';
                    elseif ($filter_status == 4) echo '已取消发票列表';
                    else echo '全部发票列表';
                    ?>
                </h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>订单编号</th>
                            <th>客户名称</th>
                            <th>发票抬头</th>
                            <th>发票类型</th>
                            <th>发票号码</th>
                            <th>金额</th>
                            <th>状态</th>
                            <th>申请时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($invoices)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无发票数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($invoices as $invoice): ?>
                                <tr>
                                    <td><?php echo $invoice['id']; ?></td>
                                    <td><?php echo htmlspecialchars($invoice['order_no']); ?></td>
                                    <td><?php echo htmlspecialchars($invoice['client_name']); ?></td>
                                    <td><?php echo htmlspecialchars($invoice['title']); ?></td>
                                    <td><?php echo $invoice['invoice_type'] == 1 ? '普通发票' : '增值税专用发票'; ?></td>
                                    <td><?php echo $invoice['invoice_no'] ? htmlspecialchars($invoice['invoice_no']) : '-'; ?></td>
                                    <td><?php echo number_format($invoice['amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($invoice['status'] == 1) echo '<span class="status-pending">申请中</span>';
                                        elseif ($invoice['status'] == 2) echo '<span class="status-pending">已开票</span>';
                                        elseif ($invoice['status'] == 3) echo '<span class="status-active">已寄出</span>';
                                        elseif ($invoice['status'] == 4) echo '<span class="status-inactive">已取消</span>';
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($invoice['create_time'])); ?></td>
                                    <td>
                                        <?php if ($invoice['status'] < 3): // 不是已寄出或已取消 
                                        ?>
                                            <a href="invoice.php?action=update&id=<?php echo $invoice['id']; ?><?php echo $filter_status ? '&status=' . $filter_status : ''; ?>" class="btn btn-sm btn-edit">更新状态</a>
                                        <?php else: ?>
                                            <span class="text-muted">无需操作</span>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 状态说明 -->
            <div class="info-box">
                <h3>发票状态说明</h3>
                <ul>
                    <li><strong>申请中</strong>：已提交开票申请，等待财务开票。可以更新为"已开票"或"已取消"。</li>
                    <li><strong>已开票</strong>：发票已开具，等待寄送给客户。可以更新为"已寄出"或"已取消"。</li>
                    <li><strong>已寄出</strong>：发票已寄送给客户。状态不可再更改。</li>
                    <li><strong>已取消</strong>：发票申请已取消。状态不可再更改。</li>
                </ul>
            </div>

            <!-- 说明信息 -->
            <div class="info-box">
                <h3>发票申请说明</h3>
                <ul>
                    <li>只能为已支付且未取消的订单申请开票。</li>
                    <li>每个订单最多只能有一个有效的发票申请（已取消的不计算）。</li>
                    <li>增值税专用发票必须填写税号。</li>
                    <li>发票一旦寄出或取消，状态将不可再更改。</li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>