<?php
require_once '../database_config.php';

// 检查会话中是否有成功消息
if (isset($_SESSION['success_message'])) {
    $success = $_SESSION['success_message'];
    unset($_SESSION['success_message']); // 删除会话中的消息，避免重复显示
}

// 检查用户是否有权限访问此页面
check_permission_or_die('order_refund');

// 记录访问日志
record_log('访问退款管理页面');

// 获取筛选参数
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;

// 处理退款申请和状态更新
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 申请退款
    if ($_POST['action'] == 'apply') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $reason = isset($_POST['reason']) ? trim($_POST['reason']) : '';

        if ($order_id <= 0 || $amount <= 0 || empty($reason)) {
            $error = '请填写完整的退款申请信息！';
        } else {
            try {
                // 检查订单是否存在且状态有效
                $stmt = $pdo->prepare("SELECT id, order_no, amount, status FROM order_orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $order = $stmt->fetch();

                if (!$order) {
                    $error = '订单不存在！';
                } elseif ($order['status'] == 5) {
                    $error = '已取消的订单不能申请退款！';
                } elseif ($amount > $order['amount']) {
                    $error = '退款金额不能大于订单金额！';
                } else {
                    // 生成退款编号
                    $refund_no = 'TK-' . date('Ymd') . rand(1000, 9999);

                    // 添加退款申请
                    $stmt = $pdo->prepare("
                        INSERT INTO order_refunds
                        (order_id, refund_no, amount, type, reason, status)
                        VALUES (?, ?, ?, ?, ?, 1)
                    ");
                    $result = $stmt->execute([$order_id, $refund_no, $amount, $type, $reason]);

                    if ($result) {
                        record_log("申请退款：订单 {$order['order_no']}，金额：{$amount}，类型：" . ($type == 1 ? '退款' : '退货退款'));
                        $_SESSION['success_message'] = '退款申请提交成功！';

                        // 重定向到列表页面
                        header('Location: refund.php');
                        exit;
                    } else {
                        $error = '退款申请提交失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 更新退款状态
    elseif ($_POST['action'] == 'update_status') {
        $refund_id = isset($_POST['refund_id']) ? intval($_POST['refund_id']) : 0;
        $new_status = isset($_POST['new_status']) ? intval($_POST['new_status']) : 0;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($refund_id <= 0 || $new_status < 1 || $new_status > 4) {
            $error = '参数无效！';
        } else {
            try {
                // 获取当前退款信息
                $stmt = $pdo->prepare("
                    SELECT r.*, o.order_no, o.amount as order_amount
                    FROM order_refunds r
                    JOIN order_orders o ON r.order_id = o.id
                    WHERE r.id = ?
                ");
                $stmt->execute([$refund_id]);
                $refund = $stmt->fetch();

                if (!$refund) {
                    $error = '退款记录不存在！';
                } else {
                    // 检查状态更新是否有效
                    $valid_update = false;
                    $current_status = $refund['status'];

                    // 状态更新规则：
                    // 1(申请中) -> 2(审核中)
                    // 2(审核中) -> 3(已批准)或4(已拒绝)
                    // 3(已批准) -> 不能更改
                    // 4(已拒绝) -> 不能更改

                    if ($current_status == 1 && $new_status == 2) {
                        $valid_update = true;
                    } elseif ($current_status == 2 && ($new_status == 3 || $new_status == 4)) {
                        $valid_update = true;
                    } elseif ($current_status == $new_status) {
                        $error = '退款已经是该状态，无需更新！';
                    } else {
                        $error = '无效的状态更新！只能按照状态流程进行更新。';
                    }

                    if ($valid_update) {
                        // 添加所有需要更新的字段到$sql_parts
                        $sql_parts = ["status = ?"];
                        $params = [$new_status];

                        // 如果是审批操作，记录审批人
                        if (($new_status == 3 || $new_status == 4) && $current_status == 2) {
                            $sql_parts[] = "approver_id = ?";
                            $params[] = $_SESSION['user_id'];
                        }

                        // 添加备注（如果有）
                        if (!empty($remark)) {
                            $sql_parts[] = "remark = ?";
                            $params[] = $remark;
                        }

                        // 构建完整SQL语句
                        $sql = "UPDATE order_refunds SET " . implode(", ", $sql_parts) . " WHERE id = ?";
                        $params[] = $refund_id;

                        $stmt = $pdo->prepare($sql);
                        $result = $stmt->execute($params);

                        if ($result) {
                            // 如果退款被批准且是退货退款，则更新订单状态为已取消
                            if ($new_status == 3 && $refund['type'] == 2 && $refund['amount'] == $refund['order_amount']) {
                                $stmt = $pdo->prepare("UPDATE order_orders SET status = 5 WHERE id = ?");
                                $stmt->execute([$refund['order_id']]);
                                record_log("订单 {$refund['order_no']} 因退货退款已取消");
                            }

                            // 获取状态文本
                            $status_text = '';
                            if ($new_status == 1) $status_text = '申请中';
                            elseif ($new_status == 2) $status_text = '审核中';
                            elseif ($new_status == 3) $status_text = '已批准';
                            elseif ($new_status == 4) $status_text = '已拒绝';

                            record_log("更新退款状态：订单 {$refund['order_no']}，新状态：{$status_text}");
                            $_SESSION['success_message'] = "退款状态已更新为：{$status_text}！";

                            // 重定向回退款页面
                            header('Location: refund.php' . ($filter_status ? '?status=' . $filter_status : ''));
                            exit;
                        } else {
                            $error = '退款状态更新失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 状态筛选查询条件
$status_condition = '';
$status_params = [];
if ($filter_status > 0) {
    $status_condition = " WHERE r.status = ?";
    $status_params = [$filter_status];
}

// 获取所有退款记录
try {
    $sql = "
        SELECT r.*, o.order_no, o.client_id, c.client_name, u.username as approver_name
        FROM order_refunds r
        JOIN order_orders o ON r.order_id = o.id
        JOIN crm_clients c ON o.client_id = c.id
        LEFT JOIN sys_users u ON r.approver_id = u.id
        {$status_condition}
        ORDER BY r.create_time DESC
    ";

    $stmt = $pdo->prepare($sql);
    if (!empty($status_params)) {
        $stmt->execute($status_params);
    } else {
        $stmt->execute();
    }

    $refunds = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取退款列表失败：' . $e->getMessage();
    $refunds = [];
}

// 获取各状态退款数量
try {
    $stmt = $pdo->query("
        SELECT status, COUNT(*) as count 
        FROM order_refunds 
        GROUP BY status
    ");
    $status_counts = [];
    while ($row = $stmt->fetch()) {
        $status_counts[$row['status']] = $row['count'];
    }
} catch (PDOException $e) {
    $error = '获取退款状态统计失败：' . $e->getMessage();
    $status_counts = [];
}

// 获取总退款数
$total_refunds = array_sum($status_counts);

// 获取可以申请退款的订单（未取消的订单）
try {
    $stmt = $pdo->query("
        SELECT o.*, c.client_name
        FROM order_orders o
        JOIN crm_clients c ON o.client_id = c.id
        WHERE o.status != 5
        ORDER BY o.create_time DESC
    ");
    $available_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取可申请退款的订单失败：' . $e->getMessage();
    $available_orders = [];
}

// 判断是否显示申请退款表单
$show_apply_form = isset($_GET['action']) && $_GET['action'] == 'apply';

// 判断是否显示状态更新表单
$show_update_form = false;
$refund_to_update = null;

// 显示状态更新表单
if (isset($_GET['action']) && $_GET['action'] == 'update' && isset($_GET['id'])) {
    $show_update_form = true;
    $refund_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT r.*, o.order_no, o.amount as order_amount, c.client_name
            FROM order_refunds r
            JOIN order_orders o ON r.order_id = o.id
            JOIN crm_clients c ON o.client_id = c.id
            WHERE r.id = ?
        ");
        $stmt->execute([$refund_id]);
        $refund_to_update = $stmt->fetch();

        if (!$refund_to_update) {
            $error = '退款记录不存在！';
            $show_update_form = false;
        } elseif ($refund_to_update['status'] == 3 || $refund_to_update['status'] == 4) {
            $error = '已批准或已拒绝的退款不能再更新状态！';
            $show_update_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取退款信息失败：' . $e->getMessage();
        $show_update_form = false;
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>退款管理</h2>
            <div class="breadcrumb">
                <a href="index.php">订单管理</a> &gt; 退款管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 退款状态统计 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>全部退款</h3>
                    <div class="number"><?php echo $total_refunds; ?></div>
                    <div class="desc"><a href="refund.php">查看全部</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>申请中</h3>
                    <div class="number"><?php echo isset($status_counts[1]) ? $status_counts[1] : 0; ?></div>
                    <div class="desc"><a href="refund.php?status=1">筛选查看</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>审核中</h3>
                    <div class="number"><?php echo isset($status_counts[2]) ? $status_counts[2] : 0; ?></div>
                    <div class="desc"><a href="refund.php?status=2">筛选查看</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已批准</h3>
                    <div class="number"><?php echo isset($status_counts[3]) ? $status_counts[3] : 0; ?></div>
                    <div class="desc"><a href="refund.php?status=3">筛选查看</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已拒绝</h3>
                    <div class="number"><?php echo isset($status_counts[4]) ? $status_counts[4] : 0; ?></div>
                    <div class="desc"><a href="refund.php?status=4">筛选查看</a></div>
                </div>
            </div>

            <div class="action-bar">
                <a href="refund.php?action=apply" class="btn btn-add">申请退款</a>
            </div>

            <!-- 申请退款表单 -->
            <?php if ($show_apply_form): ?>
                <div class="form-container">
                    <h3>申请退款</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="apply">

                        <div class="form-group">
                            <label for="order_id">选择订单：</label>
                            <select id="order_id" name="order_id" required>
                                <option value="">请选择订单</option>
                                <?php foreach ($available_orders as $order): ?>
                                    <option value="<?php echo $order['id']; ?>" data-amount="<?php echo $order['amount']; ?>">
                                        <?php echo htmlspecialchars($order['order_no']); ?> -
                                        <?php echo htmlspecialchars($order['client_name']); ?> -
                                        <?php echo number_format($order['amount'], 2); ?>元
                                    </option>
                                <?php endforeach; ?>
                            </select>
                            <?php if (empty($available_orders)): ?>
                                <small class="text-danger">暂无可申请退款的订单</small>
                            <?php endif; ?>
                        </div>

                        <div class="form-group">
                            <label for="type">退款类型：</label>
                            <select id="type" name="type" required>
                                <option value="1">仅退款</option>
                                <option value="2">退货退款</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">退款金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0" required>
                            <small>不能大于订单金额</small>
                        </div>

                        <div class="form-group">
                            <label for="reason">退款原因：</label>
                            <textarea id="reason" name="reason" rows="3" required placeholder="请详细说明退款原因"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">提交申请</button>
                            <a href="refund.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 退款状态更新表单 -->
            <?php if ($show_update_form && $refund_to_update): ?>
                <div class="form-container">
                    <h3>更新退款状态 - 订单编号: <?php echo htmlspecialchars($refund_to_update['order_no']); ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="update_status">
                        <input type="hidden" name="refund_id" value="<?php echo $refund_to_update['id']; ?>">

                        <div class="form-group">
                            <label>客户名称：</label>
                            <div class="form-static"><?php echo htmlspecialchars($refund_to_update['client_name']); ?></div>
                        </div>

                        <div class="form-group">
                            <label>退款编号：</label>
                            <div class="form-static"><?php echo htmlspecialchars($refund_to_update['refund_no']); ?></div>
                        </div>

                        <div class="form-group">
                            <label>退款类型：</label>
                            <div class="form-static"><?php echo $refund_to_update['type'] == 1 ? '仅退款' : '退货退款'; ?></div>
                        </div>

                        <div class="form-group">
                            <label>退款金额：</label>
                            <div class="form-static"><?php echo number_format($refund_to_update['amount'], 2); ?>元</div>
                        </div>

                        <div class="form-group">
                            <label>订单金额：</label>
                            <div class="form-static"><?php echo number_format($refund_to_update['order_amount'], 2); ?>元</div>
                        </div>

                        <div class="form-group">
                            <label>退款原因：</label>
                            <div class="form-static"><?php echo htmlspecialchars($refund_to_update['reason']); ?></div>
                        </div>

                        <div class="form-group">
                            <label>当前状态：</label>
                            <div class="form-static">
                                <?php
                                if ($refund_to_update['status'] == 1) echo '<span class="status-pending">申请中</span>';
                                elseif ($refund_to_update['status'] == 2) echo '<span class="status-pending">审核中</span>';
                                ?>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="new_status">新状态：</label>
                            <select id="new_status" name="new_status" required>
                                <?php if ($refund_to_update['status'] == 1): ?>
                                    <option value="2">审核中</option>
                                <?php elseif ($refund_to_update['status'] == 2): ?>
                                    <option value="3">已批准</option>
                                    <option value="4">已拒绝</option>
                                <?php endif; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="3" placeholder="可选，输入状态更新的原因或相关信息"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">更新状态</button>
                            <a href="refund.php<?php echo $filter_status ? '?status=' . $filter_status : ''; ?>" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 退款列表 -->
            <div class="table-container">
                <h3>
                    <?php
                    if ($filter_status == 1) echo '申请中退款列表';
                    elseif ($filter_status == 2) echo '审核中退款列表';
                    elseif ($filter_status == 3) echo '已批准退款列表';
                    elseif ($filter_status == 4) echo '已拒绝退款列表';
                    else echo '全部退款列表';
                    ?>
                </h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>退款编号</th>
                            <th>订单编号</th>
                            <th>客户名称</th>
                            <th>退款类型</th>
                            <th>金额</th>
                            <th>状态</th>
                            <th>审批人</th>
                            <th>申请时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($refunds)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无退款数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($refunds as $refund): ?>
                                <tr>
                                    <td><?php echo $refund['id']; ?></td>
                                    <td><?php echo htmlspecialchars($refund['refund_no']); ?></td>
                                    <td><?php echo htmlspecialchars($refund['order_no']); ?></td>
                                    <td><?php echo htmlspecialchars($refund['client_name']); ?></td>
                                    <td><?php echo $refund['type'] == 1 ? '仅退款' : '退货退款'; ?></td>
                                    <td><?php echo number_format($refund['amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($refund['status'] == 1) echo '<span class="status-pending">申请中</span>';
                                        elseif ($refund['status'] == 2) echo '<span class="status-pending">审核中</span>';
                                        elseif ($refund['status'] == 3) echo '<span class="status-active">已批准</span>';
                                        elseif ($refund['status'] == 4) echo '<span class="status-inactive">已拒绝</span>';
                                        ?>
                                    </td>
                                    <td><?php echo $refund['approver_id'] ? htmlspecialchars($refund['approver_name']) : '-'; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($refund['create_time'])); ?></td>
                                    <td>
                                        <?php if ($refund['status'] < 3): // 不是已批准或已拒绝 
                                        ?>
                                            <a href="refund.php?action=update&id=<?php echo $refund['id']; ?><?php echo $filter_status ? '&status=' . $filter_status : ''; ?>" class="btn btn-sm btn-edit">更新状态</a>
                                        <?php else: ?>
                                            <span class="text-muted">无需操作</span>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 状态说明 -->
            <div class="info-box">
                <h3>退款状态说明</h3>
                <ul>
                    <li><strong>申请中</strong>：已提交退款申请，等待客服初步审核。可以更新为"审核中"。</li>
                    <li><strong>审核中</strong>：客服已初步审核，等待财务最终审批。可以更新为"已批准"或"已拒绝"。</li>
                    <li><strong>已批准</strong>：退款申请已批准，系统将处理退款。状态不可再更改。</li>
                    <li><strong>已拒绝</strong>：退款申请已拒绝。状态不可再更改。</li>
                </ul>
            </div>

            <!-- 说明信息 -->
            <div class="info-box">
                <h3>退款申请说明</h3>
                <ul>
                    <li>已取消的订单不能申请退款。</li>
                    <li>退款金额不能大于订单金额。</li>
                    <li>退货退款指的是客户退回商品并要求退款的情况。</li>
                    <li>仅退款是指客户保留商品但要求部分退款的情况（如服务质量问题）。</li>
                    <li>退款一旦批准或拒绝，状态将不可再更改。</li>
                    <li>如果退货退款金额等于订单总金额，系统将自动取消相关订单。</li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>