<?php
require_once '../database_config.php';

// 检查会话中是否有成功消息
if (isset($_SESSION['success_message'])) {
    $success = $_SESSION['success_message'];
    unset($_SESSION['success_message']); // 删除会话中的消息，避免重复显示
}

// 检查用户是否有权限访问此页面
check_permission_or_die('order_review');

// 记录访问日志
record_log('访问订单审核页面');

// 处理订单审核
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 审核通过/发货
    if ($_POST['action'] == 'approve') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $shipping_info = isset($_POST['shipping_info']) ? trim($_POST['shipping_info']) : '';

        if ($order_id <= 0) {
            $error = '无效的订单ID！';
        } else {
            try {
                // 获取当前订单状态
                $stmt = $pdo->prepare("SELECT status, order_no FROM order_orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $current_order = $stmt->fetch();

                if (!$current_order) {
                    $error = '订单不存在！';
                } else {
                    // 检查订单状态是否为已支付
                    if ($current_order['status'] != 2) {
                        $error = '只能审核已支付状态的订单！';
                    } else {
                        // 更新订单状态为已发货，并记录审核人
                        $stmt = $pdo->prepare("UPDATE order_orders SET status = 3, approver_id = ?, remark = CONCAT(IFNULL(remark, ''), '\n发货信息: ', ?), update_time = NOW() WHERE id = ?");
                        $result = $stmt->execute([$_SESSION['user_id'], $shipping_info, $order_id]);

                        if ($result) {
                            record_log("审核通过订单：{$current_order['order_no']}，状态更新为已发货");
                            $_SESSION['success_message'] = '订单审核通过，已更新为已发货状态！';
                            header('Location: review.php');
                            exit;
                        } else {
                            $error = '订单审核操作失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 拒绝订单
    elseif ($_POST['action'] == 'reject') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $reject_reason = isset($_POST['reject_reason']) ? trim($_POST['reject_reason']) : '';

        if ($order_id <= 0) {
            $error = '无效的订单ID！';
        } elseif (empty($reject_reason)) {
            $error = '请填写拒绝原因！';
        } else {
            try {
                // 获取当前订单状态
                $stmt = $pdo->prepare("SELECT status, order_no FROM order_orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $current_order = $stmt->fetch();

                if (!$current_order) {
                    $error = '订单不存在！';
                } else {
                    // 检查订单状态是否为已支付
                    if ($current_order['status'] != 2) {
                        $error = '只能审核已支付状态的订单！';
                    } else {
                        // 更新订单状态为已取消，并记录审核人和拒绝原因
                        $stmt = $pdo->prepare("UPDATE order_orders SET status = 5, approver_id = ?, remark = CONCAT(IFNULL(remark, ''), '\n拒绝原因: ', ?), update_time = NOW() WHERE id = ?");
                        $result = $stmt->execute([$_SESSION['user_id'], $reject_reason, $order_id]);

                        if ($result) {
                            record_log("拒绝订单：{$current_order['order_no']}，原因：{$reject_reason}");
                            $_SESSION['success_message'] = '订单已拒绝，状态更新为已取消！';
                            header('Location: review.php');
                            exit;
                        } else {
                            $error = '订单拒绝操作失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 标记为已完成
    elseif ($_POST['action'] == 'complete') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;

        if ($order_id <= 0) {
            $error = '无效的订单ID！';
        } else {
            try {
                // 获取当前订单状态
                $stmt = $pdo->prepare("SELECT status, order_no FROM order_orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $current_order = $stmt->fetch();

                if (!$current_order) {
                    $error = '订单不存在！';
                } else {
                    // 检查订单状态是否为已发货
                    if ($current_order['status'] != 3) {
                        $error = '只能将已发货状态的订单标记为已完成！';
                    } else {
                        // 更新订单状态为已完成
                        $stmt = $pdo->prepare("UPDATE order_orders SET status = 4, update_time = NOW() WHERE id = ?");
                        $result = $stmt->execute([$order_id]);

                        if ($result) {
                            record_log("完成订单：{$current_order['order_no']}");
                            $_SESSION['success_message'] = '订单已标记为完成！';
                            header('Location: review.php');
                            exit;
                        } else {
                            $error = '订单完成操作失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取待审核订单（已支付状态）
try {
    $stmt = $pdo->query("
        SELECT o.*, c.client_name, sc.contract_no, u.username as creator_name
        FROM order_orders o
        JOIN crm_clients c ON o.client_id = c.id
        LEFT JOIN sales_contracts sc ON o.contract_id = sc.id
        JOIN sys_users u ON o.creator_id = u.id
        WHERE o.status = 2
        ORDER BY o.create_time DESC
    ");
    $pending_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取待审核订单失败：' . $e->getMessage();
    $pending_orders = [];
}

// 获取已发货但未完成的订单
try {
    $stmt = $pdo->query("
        SELECT o.*, c.client_name, sc.contract_no, u.username as creator_name, 
               a.username as approver_name
        FROM order_orders o
        JOIN crm_clients c ON o.client_id = c.id
        LEFT JOIN sales_contracts sc ON o.contract_id = sc.id
        JOIN sys_users u ON o.creator_id = u.id
        LEFT JOIN sys_users a ON o.approver_id = a.id
        WHERE o.status = 3
        ORDER BY o.update_time DESC
    ");
    $shipped_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取已发货订单失败：' . $e->getMessage();
    $shipped_orders = [];
}

// 获取最近完成或取消的订单（最近7天）
try {
    $stmt = $pdo->query("
        SELECT o.*, c.client_name, sc.contract_no, u.username as creator_name, 
               a.username as approver_name
        FROM order_orders o
        JOIN crm_clients c ON o.client_id = c.id
        LEFT JOIN sales_contracts sc ON o.contract_id = sc.id
        JOIN sys_users u ON o.creator_id = u.id
        LEFT JOIN sys_users a ON o.approver_id = a.id
        WHERE o.status IN (4, 5) AND o.update_time >= DATE_SUB(NOW(), INTERVAL 7 DAY)
        ORDER BY o.update_time DESC
    ");
    $recent_completed_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取最近完成订单失败：' . $e->getMessage();
    $recent_completed_orders = [];
}

// 判断是否显示审核表单
$show_approve_form = false;
$show_reject_form = false;
$order_to_approve = null;

// 显示审核表单
if (isset($_GET['action']) && $_GET['action'] == 'approve' && isset($_GET['id'])) {
    $show_approve_form = true;
    $order_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT o.*, c.client_name
            FROM order_orders o
            JOIN crm_clients c ON o.client_id = c.id
            WHERE o.id = ? AND o.status = 2
        ");
        $stmt->execute([$order_id]);
        $order_to_approve = $stmt->fetch();

        if (!$order_to_approve) {
            $error = '订单不存在或状态不是已支付！';
            $show_approve_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取订单信息失败：' . $e->getMessage();
        $show_approve_form = false;
    }
}

// 显示拒绝表单
if (isset($_GET['action']) && $_GET['action'] == 'reject' && isset($_GET['id'])) {
    $show_reject_form = true;
    $order_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT o.*, c.client_name
            FROM order_orders o
            JOIN crm_clients c ON o.client_id = c.id
            WHERE o.id = ? AND o.status = 2
        ");
        $stmt->execute([$order_id]);
        $order_to_approve = $stmt->fetch();

        if (!$order_to_approve) {
            $error = '订单不存在或状态不是已支付！';
            $show_reject_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取订单信息失败：' . $e->getMessage();
        $show_reject_form = false;
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单审核</h2>
            <div class="breadcrumb">
                <a href="index.php">订单管理</a> &gt; 订单审核
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 订单审核发货表单 -->
            <?php if ($show_approve_form && $order_to_approve): ?>
                <div class="form-container">
                    <h3>审核通过并发货 - 订单编号: <?php echo htmlspecialchars($order_to_approve['order_no']); ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="approve">
                        <input type="hidden" name="order_id" value="<?php echo $order_to_approve['id']; ?>">

                        <div class="form-group">
                            <label>客户名称：</label>
                            <div class="form-static"><?php echo htmlspecialchars($order_to_approve['client_name']); ?></div>
                        </div>

                        <div class="form-group">
                            <label>订单金额：</label>
                            <div class="form-static"><?php echo number_format($order_to_approve['amount'], 2); ?></div>
                        </div>

                        <div class="form-group">
                            <label>支付方式：</label>
                            <div class="form-static"><?php echo htmlspecialchars($order_to_approve['payment_method'] ?: '-'); ?></div>
                        </div>

                        <div class="form-group">
                            <label for="shipping_info">发货信息：</label>
                            <textarea id="shipping_info" name="shipping_info" rows="3" required placeholder="请输入物流公司、快递单号等发货信息"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">确认发货</button>
                            <a href="review.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 订单拒绝表单 -->
            <?php if ($show_reject_form && $order_to_approve): ?>
                <div class="form-container">
                    <h3>拒绝订单 - 订单编号: <?php echo htmlspecialchars($order_to_approve['order_no']); ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="reject">
                        <input type="hidden" name="order_id" value="<?php echo $order_to_approve['id']; ?>">

                        <div class="form-group">
                            <label>客户名称：</label>
                            <div class="form-static"><?php echo htmlspecialchars($order_to_approve['client_name']); ?></div>
                        </div>

                        <div class="form-group">
                            <label>订单金额：</label>
                            <div class="form-static"><?php echo number_format($order_to_approve['amount'], 2); ?></div>
                        </div>

                        <div class="form-group">
                            <label for="reject_reason">拒绝原因：</label>
                            <textarea id="reject_reason" name="reject_reason" rows="3" required placeholder="请详细说明拒绝订单的原因"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-danger">确认拒绝</button>
                            <a href="review.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 待审核订单列表（已支付） -->
            <div class="table-container">
                <h3>待审核订单 (已支付)</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单编号</th>
                            <th>客户名称</th>
                            <th>关联合同</th>
                            <th>金额</th>
                            <th>支付方式</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($pending_orders)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无待审核订单</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($pending_orders as $order): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                    <td><?php echo htmlspecialchars($order['client_name']); ?></td>
                                    <td><?php echo $order['contract_no'] ? htmlspecialchars($order['contract_no']) : '-'; ?></td>
                                    <td><?php echo number_format($order['amount'], 2); ?></td>
                                    <td><?php echo htmlspecialchars($order['payment_method'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($order['creator_name']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></td>
                                    <td>
                                        <a href="review.php?action=approve&id=<?php echo $order['id']; ?>" class="btn btn-sm btn-success">审核通过</a>
                                        <a href="review.php?action=reject&id=<?php echo $order['id']; ?>" class="btn btn-sm btn-danger">拒绝</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 已发货订单列表 -->
            <div class="table-container">
                <h3>已发货订单 (待完成)</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单编号</th>
                            <th>客户名称</th>
                            <th>金额</th>
                            <th>发货时间</th>
                            <th>审核人</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($shipped_orders)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无已发货订单</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($shipped_orders as $order): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                    <td><?php echo htmlspecialchars($order['client_name']); ?></td>
                                    <td><?php echo number_format($order['amount'], 2); ?></td>
                                    <td><?php echo $order['update_time'] ? date('Y-m-d H:i', strtotime($order['update_time'])) : '-'; ?></td>
                                    <td><?php echo htmlspecialchars($order['approver_name'] ?: '-'); ?></td>
                                    <td>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="complete">
                                            <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-primary" onclick="return confirm('确定要将订单 \'<?php echo htmlspecialchars($order['order_no']); ?>\' 标记为已完成吗？');">标记完成</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 最近完成或取消的订单 -->
            <div class="table-container">
                <h3>最近完成/取消的订单 (7天内)</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单编号</th>
                            <th>客户名称</th>
                            <th>金额</th>
                            <th>状态</th>
                            <th>完成/取消时间</th>
                            <th>审核人</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($recent_completed_orders)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无最近完成或取消的订单</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($recent_completed_orders as $order): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                    <td><?php echo htmlspecialchars($order['client_name']); ?></td>
                                    <td><?php echo number_format($order['amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($order['status'] == 4) echo '<span class="status-active">已完成</span>';
                                        elseif ($order['status'] == 5) echo '<span class="status-inactive">已取消</span>';
                                        ?>
                                    </td>
                                    <td><?php echo $order['update_time'] ? date('Y-m-d H:i', strtotime($order['update_time'])) : '-'; ?></td>
                                    <td><?php echo htmlspecialchars($order['approver_name'] ?: '-'); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>