<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('performance_target');

// 记录访问日志
record_log('访问销售目标设定页面');

// 检查当前用户是否为管理员(假设角色ID=1为管理员) - 移到最前面
$is_admin = ($_SESSION['role_id'] == 1);

// 添加/编辑目标处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加目标
    if ($_POST['action'] == 'add') {
        $year = isset($_POST['year']) ? intval($_POST['year']) : date('Y');
        $month = isset($_POST['month']) ? intval($_POST['month']) : date('n');
        $target_amount = isset($_POST['target_amount']) ? floatval($_POST['target_amount']) : 0;
        $target_clients = isset($_POST['target_clients']) ? intval($_POST['target_clients']) : 0;
        $team_id = isset($_POST['team_id']) && !empty($_POST['team_id']) ? intval($_POST['team_id']) : null;

        // 管理员可以为其他用户添加目标
        $user_id = isset($_POST['user_id']) && $is_admin ? intval($_POST['user_id']) : $_SESSION['user_id'];

        if ($target_amount <= 0 || $target_clients <= 0) {
            $error = '请填写有效的目标销售额和目标客户数！';
        } else {
            try {
                // 检查是否已存在该月份的目标
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM perf_assessments WHERE user_id = ? AND year = ? AND month = ?");
                $stmt->execute([$_SESSION['user_id'], $year, $month]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该月份的目标已存在，请使用编辑功能！';
                } else {
                    // 添加目标
                    $stmt = $pdo->prepare("INSERT INTO perf_assessments (user_id, team_id, year, month, target_amount, target_clients) VALUES (?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$user_id, $team_id, $year, $month, $target_amount, $target_clients]);

                    if ($result) {
                        record_log("设定{$year}年{$month}月销售目标");
                        $success = '销售目标设定成功！';
                        // 重定向到没有参数的页面
                        header('Location: target.php?success=add');
                        exit;
                    } else {
                        $error = '销售目标设定失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑目标
    elseif ($_POST['action'] == 'edit') {
        $assessment_id = isset($_POST['assessment_id']) ? intval($_POST['assessment_id']) : 0;
        $target_amount = isset($_POST['target_amount']) ? floatval($_POST['target_amount']) : 0;
        $target_clients = isset($_POST['target_clients']) ? intval($_POST['target_clients']) : 0;
        $team_id = isset($_POST['team_id']) && !empty($_POST['team_id']) ? intval($_POST['team_id']) : null;

        // 管理员可以修改用户ID
        $user_id = isset($_POST['user_id']) && $is_admin ? intval($_POST['user_id']) : $_SESSION['user_id'];

        if ($assessment_id <= 0 || $target_amount <= 0 || $target_clients <= 0) {
            $error = '请填写有效的目标销售额和目标客户数！';
        } else {
            try {
                // 验证目标记录是否存在，管理员可以编辑任何人的记录
                if ($is_admin) {
                    $stmt = $pdo->prepare("SELECT * FROM perf_assessments WHERE id = ?");
                    $stmt->execute([$assessment_id]);
                } else {
                    $stmt = $pdo->prepare("SELECT * FROM perf_assessments WHERE id = ? AND user_id = ?");
                    $stmt->execute([$assessment_id, $_SESSION['user_id']]);
                }
                $assessment = $stmt->fetch();

                if (!$assessment) {
                    $error = '目标记录不存在或您没有权限编辑！';
                } else {
                    // 更新目标
                    if ($is_admin) {
                        // 管理员可以修改用户ID
                        $stmt = $pdo->prepare("UPDATE perf_assessments SET target_amount = ?, target_clients = ?, team_id = ?, user_id = ? WHERE id = ?");
                        $result = $stmt->execute([$target_amount, $target_clients, $team_id, $user_id, $assessment_id]);
                    } else {
                        $stmt = $pdo->prepare("UPDATE perf_assessments SET target_amount = ?, target_clients = ?, team_id = ? WHERE id = ?");
                        $result = $stmt->execute([$target_amount, $target_clients, $team_id, $assessment_id]);
                    }

                    if ($result) {
                        record_log("更新{$assessment['year']}年{$assessment['month']}月销售目标");
                        $success = '销售目标更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: target.php?success=edit');
                        exit;
                    } else {
                        $error = '销售目标更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取筛选条件
$filter_year = isset($_GET['year']) ? intval($_GET['year']) : 0; // 0表示所有年份
$filter_month = isset($_GET['month']) ? intval($_GET['month']) : 0; // 0表示所有月份
$filter_user = isset($_GET['user_id']) ? intval($_GET['user_id']) : ($_SESSION['role_id'] == 1 ? 0 : $_SESSION['user_id']); // 管理员默认查看所有用户

// 构建查询条件
$filter_where = "";

// 基于用户权限和筛选条件构建WHERE子句
if ($_SESSION['role_id'] == 1 && $filter_user > 0) {
    // 管理员查看特定用户
    $filter_where = "WHERE a.user_id = {$filter_user}";
} else if ($_SESSION['role_id'] == 1) {
    // 管理员查看所有用户
    $filter_where = "WHERE 1=1";
} else {
    // 普通用户只能查看自己
    $filter_where = "WHERE a.user_id = {$_SESSION['user_id']}";
}

// 添加年份筛选
if ($filter_year > 0) {
    $filter_where .= " AND a.year = {$filter_year}";
}

// 添加月份筛选
if ($filter_month > 0) {
    $filter_where .= " AND a.month = {$filter_month}";
}

// 获取所有销售目标
try {
    $stmt = $pdo->query("
        SELECT a.*, t.team_name 
        FROM perf_assessments a
        LEFT JOIN perf_teams t ON a.team_id = t.id
        {$filter_where}
        ORDER BY a.year DESC, a.month DESC
    ");
    $assessments = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售目标列表失败：' . $e->getMessage();
    $assessments = [];
}

// 获取用户所在团队列表
try {
    $stmt = $pdo->prepare("
        SELECT id, team_name 
        FROM perf_teams 
        WHERE leader_id = ? OR members LIKE ?
        ORDER BY team_name
    ");
    $stmt->execute([$_SESSION['user_id'], '%,' . $_SESSION['user_id'] . ',%']);
    $teams = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取团队列表失败：' . $e->getMessage();
    $teams = [];
}

// 判断是否显示表单
$show_form = false;
$edit_assessment = null;

// 编辑目标时显示表单并获取目标信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        // 管理员可以编辑任何人的记录
        if ($is_admin) {
            $stmt = $pdo->prepare("SELECT * FROM perf_assessments WHERE id = ?");
            $stmt->execute([$edit_id]);
        } else {
            $stmt = $pdo->prepare("SELECT * FROM perf_assessments WHERE id = ? AND user_id = ?");
            $stmt->execute([$edit_id, $_SESSION['user_id']]);
        }
        $edit_assessment = $stmt->fetch();

        if (!$edit_assessment) {
            $error = '目标记录不存在或您没有权限编辑！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取目标信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加目标时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 获取可选年份
$years = [];
$current_year = date('Y');
for ($i = $current_year - 2; $i <= $current_year + 1; $i++) {
    $years[] = $i;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '销售目标设定成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '销售目标更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>销售目标设定</h2>
            <div class="breadcrumb">
                <a href="index.php">人员绩效与KPI</a> &gt; 销售目标设定
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="target.php?action=add" class="btn btn-add">添加销售目标</a>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="year">年份：</label>
                            <select id="year" name="year">
                                <option value="0" <?php echo $filter_year == 0 ? 'selected' : ''; ?>>所有年份</option>
                                <?php foreach ($years as $year): ?>
                                    <option value="<?php echo $year; ?>" <?php echo $filter_year == $year ? 'selected' : ''; ?>>
                                        <?php echo $year; ?>年
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="month">月份：</label>
                            <select id="month" name="month">
                                <option value="0" <?php echo $filter_month == 0 ? 'selected' : ''; ?>>全部月份</option>
                                <?php for ($i = 1; $i <= 12; $i++): ?>
                                    <option value="<?php echo $i; ?>" <?php echo $filter_month == $i ? 'selected' : ''; ?>>
                                        <?php echo $i; ?>月
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="target.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 管理员可以筛选用户 -->
            <?php if ($is_admin): ?>
                <div class="filter-form">
                    <h3>用户筛选</h3>
                    <form method="get" action="">
                        <input type="hidden" name="year" value="<?php echo $filter_year; ?>">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="user_id">选择用户：</label>
                                <select id="user_id" name="user_id">
                                    <option value="0">所有用户</option>
                                    <?php
                                    // 获取所有用户列表
                                    try {
                                        $stmt = $pdo->query("SELECT id, username FROM sys_users ORDER BY id");
                                        $users_list = $stmt->fetchAll();
                                        foreach ($users_list as $user) {
                                            echo '<option value="' . $user['id'] . '"' .
                                                ($filter_user == $user['id'] ? ' selected' : '') . '>' .
                                                htmlspecialchars($user['username']) . ' (ID:' . $user['id'] . ')</option>';
                                        }
                                    } catch (PDOException $e) {
                                        echo '<option value="0">获取用户列表失败</option>';
                                    }
                                    ?>
                                </select>
                            </div>
                            <div class="filter-item">
                                <button type="submit" class="btn btn-primary">筛选</button>
                            </div>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 添加/编辑销售目标表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_assessment ? '编辑销售目标' : '添加销售目标'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_assessment ? 'edit' : 'add'; ?>">
                        <?php if ($edit_assessment): ?>
                            <input type="hidden" name="assessment_id" value="<?php echo $edit_assessment['id']; ?>">
                        <?php endif; ?>

                        <?php if (!$edit_assessment): ?>
                            <div class="form-group">
                                <label for="year">年份：</label>
                                <select id="year" name="year" required>
                                    <?php foreach ($years as $year): ?>
                                        <option value="<?php echo $year; ?>" <?php echo $year == date('Y') ? 'selected' : ''; ?>>
                                            <?php echo $year; ?>年
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="month">月份：</label>
                                <select id="month" name="month" required>
                                    <?php for ($i = 1; $i <= 12; $i++): ?>
                                        <option value="<?php echo $i; ?>" <?php echo $i == date('n') ? 'selected' : ''; ?>>
                                            <?php echo $i; ?>月
                                        </option>
                                    <?php endfor; ?>
                                </select>
                            </div>
                        <?php else: ?>
                            <div class="form-group">
                                <label>年月：</label>
                                <div class="form-control-static">
                                    <?php echo $edit_assessment['year']; ?>年<?php echo $edit_assessment['month']; ?>月
                                </div>
                            </div>
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="target_amount">目标销售额：</label>
                            <input type="number" id="target_amount" name="target_amount" min="0" step="0.01" value="<?php echo $edit_assessment ? $edit_assessment['target_amount'] : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="target_clients">目标客户数：</label>
                            <input type="number" id="target_clients" name="target_clients" min="0" step="1" value="<?php echo $edit_assessment ? $edit_assessment['target_clients'] : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="team_id">关联团队：</label>
                            <select id="team_id" name="team_id">
                                <option value="">-- 无关联团队（个人目标）--</option>
                                <?php foreach ($teams as $team): ?>
                                    <option value="<?php echo $team['id']; ?>" <?php echo ($edit_assessment && $edit_assessment['team_id'] == $team['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($team['team_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <!-- 只有管理员可以更改目标归属用户 -->
                        <?php if ($is_admin): ?>
                            <div class="form-group">
                                <label for="user_id">归属用户：</label>
                                <select id="user_id" name="user_id" required>
                                    <?php
                                    // 获取所有用户
                                    try {
                                        $stmt = $pdo->query("SELECT id, username FROM sys_users ORDER BY id");
                                        $all_users = $stmt->fetchAll();
                                        foreach ($all_users as $user) {
                                            $selected = ($edit_assessment && $edit_assessment['user_id'] == $user['id']) ? 'selected' : '';
                                            echo "<option value='{$user['id']}' {$selected}>{$user['username']} (ID:{$user['id']})</option>";
                                        }
                                    } catch (PDOException $e) {
                                        echo "<option value='{$_SESSION['user_id']}'>获取用户列表失败</option>";
                                    }
                                    ?>
                                </select>
                            </div>
                        <?php endif; ?>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="target.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 销售目标列表 -->
            <div class="table-container">
                <h3><?php echo $filter_year; ?>年销售目标列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>年月</th>
                            <th>目标销售额</th>
                            <th>实际销售额</th>
                            <th>完成率</th>
                            <th>目标客户数</th>
                            <th>实际客户数</th>
                            <th>完成率</th>
                            <th>关联团队</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($assessments)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无销售目标数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($assessments as $assessment): ?>
                                <tr>
                                    <td><?php echo $assessment['year']; ?>年<?php echo $assessment['month']; ?>月</td>
                                    <td><?php echo number_format($assessment['target_amount'], 2); ?></td>
                                    <td><?php echo number_format($assessment['actual_amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($assessment['target_amount'] > 0) {
                                            $sales_rate = ($assessment['actual_amount'] / $assessment['target_amount']) * 100;
                                            echo number_format($sales_rate, 2) . '%';

                                            if ($sales_rate >= 100) {
                                                echo ' <span style="color: #28a745;">(已达标)</span>';
                                            } elseif ($sales_rate >= 80) {
                                                echo ' <span style="color: #ffc107;">(接近达标)</span>';
                                            } else {
                                                echo ' <span style="color: #dc3545;">(未达标)</span>';
                                            }
                                        } else {
                                            echo '-';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $assessment['target_clients']; ?></td>
                                    <td><?php echo $assessment['actual_clients']; ?></td>
                                    <td>
                                        <?php
                                        if ($assessment['target_clients'] > 0) {
                                            $client_rate = ($assessment['actual_clients'] / $assessment['target_clients']) * 100;
                                            echo number_format($client_rate, 2) . '%';

                                            if ($client_rate >= 100) {
                                                echo ' <span style="color: #28a745;">(已达标)</span>';
                                            } elseif ($client_rate >= 80) {
                                                echo ' <span style="color: #ffc107;">(接近达标)</span>';
                                            } else {
                                                echo ' <span style="color: #dc3545;">(未达标)</span>';
                                            }
                                        } else {
                                            echo '-';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $assessment['team_name'] ? htmlspecialchars($assessment['team_name']) : '-'; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($assessment['create_time'])); ?></td>
                                    <td>
                                        <a href="target.php?action=edit&id=<?php echo $assessment['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 提示信息 -->
            <div class="info-box">
                <h3>关于销售目标设定</h3>
                <p>销售目标设定功能帮助您：</p>
                <ul>
                    <li><strong>明确月度目标</strong>：设定每月的销售目标和客户开发目标。</li>
                    <li><strong>跟踪完成情况</strong>：实时查看目标的完成率，了解绩效表现。</li>
                    <li><strong>团队协作</strong>：将个人目标与团队目标关联，协同工作。</li>
                    <li><strong>绩效评估基础</strong>：目标完成情况是绩效考核的重要依据。</li>
                </ul>
                <p>提示：设定合理可行的目标，既有挑战性又能激发积极性，有助于提高业绩。</p>
            </div>
        </div>
    </div>
</body>

</html>