<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('product_analysis');

// 记录访问日志
record_log('访问产品销售分析页面');

// 获取时间段参数
$period = isset($_GET['period']) ? $_GET['period'] : 'month';
$category = isset($_GET['category']) ? intval($_GET['category']) : 0;

// 根据选择的时间段设置查询日期范围
$start_date = '';
$end_date = date('Y-m-d');
$period_name = '';

switch ($period) {
    case 'week':
        $start_date = date('Y-m-d', strtotime('-7 days'));
        $period_name = '最近7天';
        break;
    case 'month':
        $start_date = date('Y-m-01');
        $period_name = '本月';
        break;
    case 'lastmonth':
        $start_date = date('Y-m-01', strtotime('-1 month'));
        $end_date = date('Y-m-t', strtotime('-1 month'));
        $period_name = '上月';
        break;
    case 'quarter':
        $current_month = date('n');
        $current_quarter = ceil($current_month / 3);
        $start_date = date('Y-' . (($current_quarter - 1) * 3 + 1) . '-01');
        $period_name = '本季度';
        break;
    case 'year':
        $start_date = date('Y-01-01');
        $period_name = '本年度';
        break;
    case 'custom':
        $start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
        $end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
        $period_name = $start_date . ' 至 ' . $end_date;
        break;
    default:
        $start_date = date('Y-m-01');
        $period_name = '本月';
}

// 获取产品分类
try {
    $stmt = $pdo->query("SELECT DISTINCT category FROM product_items ORDER BY category");
    $categories = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取产品分类失败：' . $e->getMessage();
    $categories = [];
}

// 构建分类查询条件
$category_condition = '';
if ($category > 0) {
    $category_condition = " AND p.category = {$category} ";
}

// 获取热销产品排行（通过库存出库记录）
try {
    $stmt = $pdo->prepare("
        SELECT p.id, p.product_code, p.name, p.category, p.price, p.unit,
               SUM(l.quantity) as total_quantity,
               SUM(l.quantity * p.price) as total_sales
        FROM product_items p
        JOIN product_stock_logs l ON p.id = l.product_id
        WHERE l.create_time BETWEEN ? AND ?
              AND l.type = 2 /* 出库 */
              AND l.order_id IS NOT NULL /* 关联到订单的出库 */
              {$category_condition}
        GROUP BY p.id
        ORDER BY total_sales DESC
        LIMIT 10
    ");
    $stmt->execute([$start_date, $end_date]);
    $hot_products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取热销产品数据失败：' . $e->getMessage();
    $hot_products = [];
}

// 获取滞销产品排行（在售但无出库记录或出库量少的产品）
try {
    $stmt = $pdo->prepare("
        SELECT p.id, p.product_code, p.name, p.category, p.price, p.unit,
               IFNULL(SUM(CASE WHEN l.type = 2 THEN l.quantity ELSE 0 END), 0) as total_quantity,
               IFNULL(SUM(CASE WHEN l.type = 2 THEN l.quantity * p.price ELSE 0 END), 0) as total_sales
        FROM product_items p
        LEFT JOIN product_stock_logs l ON p.id = l.product_id AND l.create_time BETWEEN ? AND ? AND l.order_id IS NOT NULL
        WHERE p.status = 1 /* 仅在售产品 */
              {$category_condition}
        GROUP BY p.id
        ORDER BY total_sales ASC, total_quantity ASC
        LIMIT 10
    ");
    $stmt->execute([$start_date, $end_date]);
    $slow_products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取滞销产品数据失败：' . $e->getMessage();
    $slow_products = [];
}

// 获取各产品类别销售占比
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE p.category
                WHEN 1 THEN '软件'
                WHEN 2 THEN '服务'
                WHEN 3 THEN '硬件'
                ELSE '其他'
            END as category_name,
            SUM(l.quantity * p.price) as total_sales,
            COUNT(DISTINCT l.order_id) as order_count
        FROM product_items p
        JOIN product_stock_logs l ON p.id = l.product_id
        WHERE l.create_time BETWEEN ? AND ?
              AND l.type = 2 /* 出库 */
              AND l.order_id IS NOT NULL /* 关联到订单的出库 */
        GROUP BY p.category
        ORDER BY total_sales DESC
    ");
    $stmt->execute([$start_date, $end_date]);
    $category_sales = $stmt->fetchAll();

    // 计算总销售额，用于计算百分比
    $total_sales_amount = 0;
    foreach ($category_sales as $cat) {
        $total_sales_amount += $cat['total_sales'];
    }
} catch (PDOException $e) {
    $error = '获取产品类别销售数据失败：' . $e->getMessage();
    $category_sales = [];
    $total_sales_amount = 0;
}

// 获取销售增长趋势（最近6个月的订单总额）
try {
    $months = [];
    $month_sales = [];

    for ($i = 5; $i >= 0; $i--) {
        $month_start = date('Y-m-01', strtotime("-{$i} month"));
        $month_end = date('Y-m-t', strtotime("-{$i} month"));
        $month_name = date('Y年m月', strtotime("-{$i} month"));

        $stmt = $pdo->prepare("
            SELECT SUM(o.amount) as month_sales
            FROM order_orders o
            WHERE o.create_time BETWEEN ? AND ?
                  AND o.status IN (2, 3, 4) /* 已支付、已发货、已完成 */
        ");
        $stmt->execute([$month_start, $month_end]);
        $result = $stmt->fetch();

        $months[] = $month_name;
        $month_sales[] = $result['month_sales'] ?: 0;
    }
} catch (PDOException $e) {
    $error = '获取销售趋势数据失败：' . $e->getMessage();
    $months = [];
    $month_sales = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>产品销售分析</h2>
            <div class="breadcrumb">
                <a href="index.php">产品管理</a> &gt; 产品销售分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 筛选条件 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="period">时间段：</label>
                            <select id="period" name="period" onchange="this.form.submit()">
                                <option value="week" <?php echo $period == 'week' ? 'selected' : ''; ?>>最近7天</option>
                                <option value="month" <?php echo $period == 'month' ? 'selected' : ''; ?>>本月</option>
                                <option value="lastmonth" <?php echo $period == 'lastmonth' ? 'selected' : ''; ?>>上月</option>
                                <option value="quarter" <?php echo $period == 'quarter' ? 'selected' : ''; ?>>本季度</option>
                                <option value="year" <?php echo $period == 'year' ? 'selected' : ''; ?>>本年度</option>
                                <option value="custom" <?php echo $period == 'custom' ? 'selected' : ''; ?>>自定义时间段</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="category">产品分类：</label>
                            <select id="category" name="category" onchange="this.form.submit()">
                                <option value="0">所有分类</option>
                                <?php foreach ($categories as $cat): ?>
                                    <option value="<?php echo $cat['category']; ?>" <?php echo $category == $cat['category'] ? 'selected' : ''; ?>>
                                        <?php
                                        if ($cat['category'] == 1) echo '软件';
                                        elseif ($cat['category'] == 2) echo '服务';
                                        elseif ($cat['category'] == 3) echo '硬件';
                                        else echo '其他';
                                        ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <?php if ($period == 'custom'): ?>
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                            </div>

                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                            </div>

                            <div class="filter-item">
                                <label>&nbsp;</label>
                                <button type="submit" class="btn btn-primary">筛选</button>
                            </div>
                        <?php endif; ?>
                    </div>
                </form>
            </div>

            <!-- 销售概览 -->
            <div>
                <h3>销售概览 - <?php echo $period_name; ?></h3>
                <div class="dashboard">
                    <div class="dashboard-card">
                        <h3>总销售额</h3>
                        <div class="number"><?php echo number_format($total_sales_amount, 2); ?></div>
                        <div class="desc">元</div>
                    </div>
                    <div class="dashboard-card">
                        <h3>产品出库量</h3>
                        <div class="number">
                            <?php
                            $total_quantity = 0;
                            foreach ($hot_products as $product) {
                                $total_quantity += $product['total_quantity'];
                            }
                            echo number_format($total_quantity);
                            ?>
                        </div>
                        <div class="desc">件</div>
                    </div>
                    <div class="dashboard-card">
                        <h3>关联订单数</h3>
                        <div class="number">
                            <?php
                            $order_count = 0;
                            foreach ($category_sales as $cat) {
                                $order_count += $cat['order_count'];
                            }
                            echo number_format($order_count);
                            ?>
                        </div>
                        <div class="desc">单</div>
                    </div>
                </div>
            </div>

            <!-- 热销产品TOP10 -->
            <div class="table-container">
                <h3>热销产品TOP10</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>产品编码</th>
                            <th>产品名称</th>
                            <th>分类</th>
                            <th>单价</th>
                            <th>出库数量</th>
                            <th>销售金额</th>
                            <th>占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($hot_products)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无销售数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($hot_products as $index => $product): ?>
                                <tr>
                                    <td><?php echo $index + 1; ?></td>
                                    <td><?php echo htmlspecialchars($product['product_code']); ?></td>
                                    <td><?php echo htmlspecialchars($product['name']); ?></td>
                                    <td>
                                        <?php
                                        if ($product['category'] == 1) echo '软件';
                                        elseif ($product['category'] == 2) echo '服务';
                                        elseif ($product['category'] == 3) echo '硬件';
                                        else echo '其他';
                                        ?>
                                    </td>
                                    <td><?php echo number_format($product['price'], 2); ?></td>
                                    <td><?php echo number_format($product['total_quantity']); ?> <?php echo htmlspecialchars($product['unit'] ?: '件'); ?></td>
                                    <td><?php echo number_format($product['total_sales'], 2); ?></td>
                                    <td><?php echo $total_sales_amount > 0 ? number_format(($product['total_sales'] / $total_sales_amount) * 100, 2) : '0.00'; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 滞销产品TOP10 -->
            <div class="table-container">
                <h3>滞销产品TOP10</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>产品编码</th>
                            <th>产品名称</th>
                            <th>分类</th>
                            <th>单价</th>
                            <th>出库数量</th>
                            <th>销售金额</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($slow_products)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($slow_products as $index => $product): ?>
                                <tr>
                                    <td><?php echo $index + 1; ?></td>
                                    <td><?php echo htmlspecialchars($product['product_code']); ?></td>
                                    <td><?php echo htmlspecialchars($product['name']); ?></td>
                                    <td>
                                        <?php
                                        if ($product['category'] == 1) echo '软件';
                                        elseif ($product['category'] == 2) echo '服务';
                                        elseif ($product['category'] == 3) echo '硬件';
                                        else echo '其他';
                                        ?>
                                    </td>
                                    <td><?php echo number_format($product['price'], 2); ?></td>
                                    <td><?php echo number_format($product['total_quantity']); ?> <?php echo htmlspecialchars($product['unit'] ?: '件'); ?></td>
                                    <td><?php echo number_format($product['total_sales'], 2); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 产品分类销售占比 -->
            <div class="table-container">
                <h3>产品分类销售占比</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>分类</th>
                            <th>销售金额</th>
                            <th>占比</th>
                            <th>关联订单数</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($category_sales)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($category_sales as $cat): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($cat['category_name']); ?></td>
                                    <td><?php echo number_format($cat['total_sales'], 2); ?></td>
                                    <td>
                                        <?php echo $total_sales_amount > 0 ? number_format(($cat['total_sales'] / $total_sales_amount) * 100, 2) : '0.00'; ?>%
                                        <div class="progress-bar">
                                            <div class="progress" style="width: <?php echo $total_sales_amount > 0 ? ($cat['total_sales'] / $total_sales_amount) * 100 : 0; ?>%;"></div>
                                        </div>
                                    </td>
                                    <td><?php echo number_format($cat['order_count']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 销售趋势 - 表格形式 -->
            <div class="table-container">
                <h3>最近6个月销售趋势</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <?php foreach ($months as $month): ?>
                                <th><?php echo $month; ?></th>
                            <?php endforeach; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <?php foreach ($month_sales as $sales): ?>
                                <td><?php echo number_format($sales, 2); ?></td>
                            <?php endforeach; ?>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>