<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('product_inventory');

// 记录访问日志
record_log('访问库存管理页面');

// 获取所有产品（用于选择产品）
try {
    $stmt = $pdo->query("SELECT id, product_code, name FROM product_items ORDER BY name");
    $products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取产品列表失败：' . $e->getMessage();
    $products = [];
}

// 添加/编辑库存处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加库存
    if ($_POST['action'] == 'add') {
        $product_id = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;
        $quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 0;
        $warehouse = isset($_POST['warehouse']) ? trim($_POST['warehouse']) : '主仓库';

        if ($product_id <= 0) {
            $error = '请选择产品！';
        } elseif ($quantity < 0) {
            $error = '库存数量不能为负数！';
        } else {
            try {
                // 检查该产品在该仓库是否已有库存记录
                $stmt = $pdo->prepare("SELECT id FROM product_inventory WHERE product_id = ? AND warehouse = ?");
                $stmt->execute([$product_id, $warehouse]);
                $existing = $stmt->fetch();

                if ($existing) {
                    $error = '该产品在指定仓库已有库存记录，请使用编辑功能或入库操作！';
                } else {
                    // 添加库存记录
                    $stmt = $pdo->prepare("INSERT INTO product_inventory (product_id, quantity, warehouse) VALUES (?, ?, ?)");
                    $result = $stmt->execute([$product_id, $quantity, $warehouse]);

                    if ($result) {
                        // 添加库存变动记录（作为初始库存）
                        $stmt = $pdo->prepare("INSERT INTO product_stock_logs (product_id, type, quantity, operator_id) VALUES (?, 1, ?, ?)");
                        $stmt->execute([$product_id, $quantity, $_SESSION['user_id']]);

                        record_log("添加库存记录：产品ID {$product_id}，数量 {$quantity}");
                        $success = '库存记录添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: inventory.php?success=add');
                        exit;
                    } else {
                        $error = '库存记录添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑库存
    elseif ($_POST['action'] == 'edit') {
        $inventory_id = isset($_POST['inventory_id']) ? intval($_POST['inventory_id']) : 0;
        $quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 0;
        $warehouse = isset($_POST['warehouse']) ? trim($_POST['warehouse']) : '主仓库';

        if ($inventory_id <= 0) {
            $error = '无效的库存记录ID！';
        } elseif ($quantity < 0) {
            $error = '库存数量不能为负数！';
        } else {
            try {
                // 获取旧库存记录，用于计算变化量和记录日志
                $stmt = $pdo->prepare("SELECT product_id, quantity FROM product_inventory WHERE id = ?");
                $stmt->execute([$inventory_id]);
                $old_inventory = $stmt->fetch();

                if (!$old_inventory) {
                    $error = '库存记录不存在！';
                } else {
                    // 更新库存记录
                    $stmt = $pdo->prepare("UPDATE product_inventory SET quantity = ?, warehouse = ? WHERE id = ?");
                    $result = $stmt->execute([$quantity, $warehouse, $inventory_id]);

                    if ($result) {
                        // 计算变化量并添加库存变动记录
                        $change = $quantity - $old_inventory['quantity'];
                        if ($change != 0) {
                            $type = $change > 0 ? 1 : 2; // 1=入库, 2=出库
                            $change_abs = abs($change);
                            $stmt = $pdo->prepare("INSERT INTO product_stock_logs (product_id, type, quantity, operator_id) VALUES (?, ?, ?, ?)");
                            $stmt->execute([$old_inventory['product_id'], $type, $change_abs, $_SESSION['user_id']]);
                        }

                        record_log("编辑库存记录：产品ID {$old_inventory['product_id']}，数量从 {$old_inventory['quantity']} 修改为 {$quantity}");
                        $success = '库存记录更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: inventory.php?success=edit');
                        exit;
                    } else {
                        $error = '库存记录更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 入库/出库操作
    elseif ($_POST['action'] == 'stockOperation') {
        $inventory_id = isset($_POST['inventory_id']) ? intval($_POST['inventory_id']) : 0;
        $type = isset($_POST['type']) ? intval($_POST['type']) : 0; // 1=入库, 2=出库
        $quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 0;
        $order_id = isset($_POST['order_id']) && !empty($_POST['order_id']) ? intval($_POST['order_id']) : null;

        if ($inventory_id <= 0) {
            $error = '无效的库存记录ID！';
        } elseif ($type != 1 && $type != 2) {
            $error = '无效的操作类型！';
        } elseif ($quantity <= 0) {
            $error = '操作数量必须大于0！';
        } else {
            try {
                // 获取库存记录
                $stmt = $pdo->prepare("SELECT id, product_id, quantity FROM product_inventory WHERE id = ?");
                $stmt->execute([$inventory_id]);
                $inventory = $stmt->fetch();

                if (!$inventory) {
                    $error = '库存记录不存在！';
                } else {
                    // 计算新库存数量
                    $new_quantity = $type == 1 ? $inventory['quantity'] + $quantity : $inventory['quantity'] - $quantity;

                    // 检查出库操作是否会导致库存不足
                    if ($type == 2 && $new_quantity < 0) {
                        $error = '库存不足，无法出库！';
                    } else {
                        // 开始事务
                        $pdo->beginTransaction();

                        try {
                            // 更新库存数量
                            $stmt = $pdo->prepare("UPDATE product_inventory SET quantity = ? WHERE id = ?");
                            $stmt->execute([$new_quantity, $inventory_id]);

                            // 添加库存变动记录
                            $stmt = $pdo->prepare("INSERT INTO product_stock_logs (product_id, type, quantity, order_id, operator_id) VALUES (?, ?, ?, ?, ?)");
                            $stmt->execute([$inventory['product_id'], $type, $quantity, $order_id, $_SESSION['user_id']]);

                            // 提交事务
                            $pdo->commit();

                            $operation_name = $type == 1 ? '入库' : '出库';
                            record_log("产品ID {$inventory['product_id']} {$operation_name}操作：数量 {$quantity}");
                            $success = $operation_name . '操作成功！';
                            // 重定向到没有参数的页面
                            header('Location: inventory.php?success=' . ($type == 1 ? 'in' : 'out'));
                            exit;
                        } catch (Exception $e) {
                            // 回滚事务
                            $pdo->rollBack();
                            throw $e;
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有库存记录
try {
    $stmt = $pdo->query("
        SELECT i.*, p.product_code, p.name as product_name, p.category, p.unit
        FROM product_inventory i
        JOIN product_items p ON i.product_id = p.id
        ORDER BY i.update_time DESC
    ");
    $inventories = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取库存列表失败：' . $e->getMessage();
    $inventories = [];
}

// 获取最近的库存变动记录
try {
    $stmt = $pdo->query("
        SELECT l.*, p.product_code, p.name as product_name, u.username as operator_name
        FROM product_stock_logs l
        JOIN product_items p ON l.product_id = p.id
        JOIN sys_users u ON l.operator_id = u.id
        ORDER BY l.create_time DESC
        LIMIT 50
    ");
    $stock_logs = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取库存变动记录失败：' . $e->getMessage();
    $stock_logs = [];
}

// 判断是否显示表单
$show_form = false;
$edit_inventory = null;
$show_operation_form = false;
$operation_inventory = null;
$operation_type = null;

// 编辑库存时显示表单并获取库存信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT i.*, p.name as product_name
            FROM product_inventory i
            JOIN product_items p ON i.product_id = p.id
            WHERE i.id = ?
        ");
        $stmt->execute([$edit_id]);
        $edit_inventory = $stmt->fetch();
        if (!$edit_inventory) {
            $error = '库存记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取库存信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加库存时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 入库/出库操作时显示表单
if (isset($_GET['action']) && ($_GET['action'] == 'in' || $_GET['action'] == 'out') && isset($_GET['id'])) {
    $show_operation_form = true;
    $operation_type = $_GET['action'] == 'in' ? 1 : 2;
    $inventory_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT i.*, p.name as product_name, p.product_code
            FROM product_inventory i
            JOIN product_items p ON i.product_id = p.id
            WHERE i.id = ?
        ");
        $stmt->execute([$inventory_id]);
        $operation_inventory = $stmt->fetch();
        if (!$operation_inventory) {
            $error = '库存记录不存在！';
            $show_operation_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取库存信息失败：' . $e->getMessage();
        $show_operation_form = false;
    }
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '库存记录添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '库存记录更新成功！';
    } elseif ($_GET['success'] == 'in') {
        $success = '入库操作成功！';
    } elseif ($_GET['success'] == 'out') {
        $success = '出库操作成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>库存管理</h2>
            <div class="breadcrumb">
                <a href="index.php">产品管理</a> &gt; 库存管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="inventory.php?action=add" class="btn btn-add">添加库存记录</a>
            </div>

            <!-- 添加/编辑库存表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_inventory ? '编辑库存记录' : '添加库存记录'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_inventory ? 'edit' : 'add'; ?>">
                        <?php if ($edit_inventory): ?>
                            <input type="hidden" name="inventory_id" value="<?php echo $edit_inventory['id']; ?>">
                        <?php endif; ?>

                        <?php if ($edit_inventory): ?>
                            <div class="form-group">
                                <label>产品名称：</label>
                                <div class="form-static"><?php echo htmlspecialchars($edit_inventory['product_name']); ?></div>
                                <input type="hidden" name="product_id" value="<?php echo $edit_inventory['product_id']; ?>">
                            </div>
                        <?php else: ?>
                            <div class="form-group">
                                <label for="product_id">产品：</label>
                                <select id="product_id" name="product_id" required>
                                    <option value="">请选择产品</option>
                                    <?php foreach ($products as $product): ?>
                                        <option value="<?php echo $product['id']; ?>"><?php echo htmlspecialchars($product['name']); ?> (<?php echo htmlspecialchars($product['product_code']); ?>)</option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="quantity">库存数量：</label>
                            <input type="number" id="quantity" name="quantity" min="0" value="<?php echo $edit_inventory ? htmlspecialchars($edit_inventory['quantity']) : '0'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="warehouse">仓库：</label>
                            <input type="text" id="warehouse" name="warehouse" value="<?php echo $edit_inventory ? htmlspecialchars($edit_inventory['warehouse']) : '主仓库'; ?>">
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="inventory.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 入库/出库操作表单 -->
            <?php if ($show_operation_form): ?>
                <div class="form-container">
                    <h3><?php echo $operation_type == 1 ? '入库操作' : '出库操作'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="stockOperation">
                        <input type="hidden" name="inventory_id" value="<?php echo $operation_inventory['id']; ?>">
                        <input type="hidden" name="type" value="<?php echo $operation_type; ?>">

                        <div class="form-group">
                            <label>产品名称：</label>
                            <div class="form-static"><?php echo htmlspecialchars($operation_inventory['product_name']); ?> (<?php echo htmlspecialchars($operation_inventory['product_code']); ?>)</div>
                        </div>

                        <div class="form-group">
                            <label>当前库存：</label>
                            <div class="form-static"><?php echo htmlspecialchars($operation_inventory['quantity']); ?></div>
                        </div>

                        <div class="form-group">
                            <label for="quantity"><?php echo $operation_type == 1 ? '入库' : '出库'; ?>数量：</label>
                            <input type="number" id="quantity" name="quantity" min="1" value="1" required>
                        </div>

                        <div class="form-group">
                            <label for="order_id">关联订单ID（可选）：</label>
                            <input type="number" id="order_id" name="order_id" min="1">
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success"><?php echo $operation_type == 1 ? '确认入库' : '确认出库'; ?></button>
                            <a href="inventory.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 库存列表 -->
            <div class="table-container">
                <h3>库存列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>产品编码</th>
                            <th>产品名称</th>
                            <th>分类</th>
                            <th>库存数量</th>
                            <th>单位</th>
                            <th>仓库</th>
                            <th>更新时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($inventories)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无库存数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($inventories as $inventory): ?>
                                <tr>
                                    <td><?php echo $inventory['id']; ?></td>
                                    <td><?php echo htmlspecialchars($inventory['product_code']); ?></td>
                                    <td><?php echo htmlspecialchars($inventory['product_name']); ?></td>
                                    <td>
                                        <?php
                                        if ($inventory['category'] == 1) echo '软件';
                                        elseif ($inventory['category'] == 2) echo '服务';
                                        else echo '硬件';
                                        ?>
                                    </td>
                                    <td><?php echo $inventory['quantity']; ?></td>
                                    <td><?php echo htmlspecialchars($inventory['unit'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($inventory['warehouse']); ?></td>
                                    <td><?php echo $inventory['update_time']; ?></td>
                                    <td>
                                        <a href="inventory.php?action=edit&id=<?php echo $inventory['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <a href="inventory.php?action=in&id=<?php echo $inventory['id']; ?>" class="btn btn-sm btn-success">入库</a>
                                        <a href="inventory.php?action=out&id=<?php echo $inventory['id']; ?>" class="btn btn-sm btn-danger">出库</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 库存变动记录 -->
            <div class="table-container">
                <h3>最近库存变动记录</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>时间</th>
                            <th>产品编码</th>
                            <th>产品名称</th>
                            <th>操作类型</th>
                            <th>数量</th>
                            <th>订单ID</th>
                            <th>操作人</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($stock_logs)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无库存变动记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($stock_logs as $log): ?>
                                <tr>
                                    <td><?php echo $log['id']; ?></td>
                                    <td><?php echo $log['create_time']; ?></td>
                                    <td><?php echo htmlspecialchars($log['product_code']); ?></td>
                                    <td><?php echo htmlspecialchars($log['product_name']); ?></td>
                                    <td>
                                        <?php echo $log['type'] == 1 ? '<span class="status-active">入库</span>' : '<span class="status-inactive">出库</span>'; ?>
                                    </td>
                                    <td><?php echo $log['quantity']; ?></td>
                                    <td><?php echo $log['order_id'] ? $log['order_id'] : '-'; ?></td>
                                    <td><?php echo htmlspecialchars($log['operator_name']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>