<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('product_price');

// 记录访问日志
record_log('访问价格策略管理页面');

// 获取所有产品（用于选择关联产品）
try {
    $stmt = $pdo->query("SELECT id, product_code, name, price FROM product_items WHERE status = 1 ORDER BY name");
    $products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取产品列表失败：' . $e->getMessage();
    $products = [];
}

// 添加/编辑价格策略处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加价格策略
    if ($_POST['action'] == 'add') {
        $product_id = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;
        $rule_name = isset($_POST['rule_name']) ? trim($_POST['rule_name']) : '';
        $client_level = isset($_POST['client_level']) && $_POST['client_level'] != '' ? intval($_POST['client_level']) : null;
        $discount = isset($_POST['discount']) ? floatval($_POST['discount']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : null;
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : null;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($product_id <= 0 || empty($rule_name) || $discount <= 0 || $discount > 100) {
            $error = '请填写完整价格策略信息！折扣率必须在0-100之间。';
        } else {
            try {
                // 检查策略名称是否已为同一产品使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM product_price_rules WHERE product_id = ? AND rule_name = ?");
                $stmt->execute([$product_id, $rule_name]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该产品已存在同名价格策略！';
                } else {
                    // 添加价格策略
                    $stmt = $pdo->prepare("INSERT INTO product_price_rules (product_id, rule_name, client_level, discount, start_date, end_date, status) VALUES (?, ?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$product_id, $rule_name, $client_level, $discount, $start_date, $end_date, $status]);

                    if ($result) {
                        record_log("添加价格策略：{$rule_name}，产品ID {$product_id}");
                        $success = '价格策略添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: price.php?success=add');
                        exit;
                    } else {
                        $error = '价格策略添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑价格策略
    elseif ($_POST['action'] == 'edit') {
        $rule_id = isset($_POST['rule_id']) ? intval($_POST['rule_id']) : 0;
        $product_id = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;
        $rule_name = isset($_POST['rule_name']) ? trim($_POST['rule_name']) : '';
        $client_level = isset($_POST['client_level']) && $_POST['client_level'] != '' ? intval($_POST['client_level']) : null;
        $discount = isset($_POST['discount']) ? floatval($_POST['discount']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : null;
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : null;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($rule_id <= 0 || $product_id <= 0 || empty($rule_name) || $discount <= 0 || $discount > 100) {
            $error = '请填写完整价格策略信息！折扣率必须在0-100之间。';
        } else {
            try {
                // 检查策略名称是否已被其他策略使用（同一产品下）
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM product_price_rules WHERE product_id = ? AND rule_name = ? AND id != ?");
                $stmt->execute([$product_id, $rule_name, $rule_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该产品已存在同名价格策略！';
                } else {
                    // 更新价格策略信息
                    $stmt = $pdo->prepare("UPDATE product_price_rules SET rule_name = ?, client_level = ?, discount = ?, start_date = ?, end_date = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$rule_name, $client_level, $discount, $start_date, $end_date, $status, $rule_id]);

                    if ($result) {
                        record_log("编辑价格策略：{$rule_name}，产品ID {$product_id}");
                        $success = '价格策略更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: price.php?success=edit');
                        exit;
                    } else {
                        $error = '价格策略更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除价格策略
    elseif ($_POST['action'] == 'delete') {
        $rule_id = isset($_POST['rule_id']) ? intval($_POST['rule_id']) : 0;

        if ($rule_id <= 0) {
            $error = '无效的价格策略ID！';
        } else {
            try {
                // 获取价格策略信息，用于日志记录
                $stmt = $pdo->prepare("SELECT rule_name, product_id FROM product_price_rules WHERE id = ?");
                $stmt->execute([$rule_id]);
                $rule = $stmt->fetch();

                if (!$rule) {
                    $error = '价格策略不存在！';
                } else {
                    // 删除价格策略
                    $stmt = $pdo->prepare("DELETE FROM product_price_rules WHERE id = ?");
                    $result = $stmt->execute([$rule_id]);

                    if ($result) {
                        record_log("删除价格策略：{$rule['rule_name']}，产品ID {$rule['product_id']}");
                        $success = '价格策略删除成功！';
                    } else {
                        $error = '价格策略删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有价格策略
try {
    $stmt = $pdo->query("
        SELECT r.*, p.product_code, p.name as product_name, p.price as standard_price
        FROM product_price_rules r
        JOIN product_items p ON r.product_id = p.id
        ORDER BY r.product_id, r.status DESC, r.start_date DESC
    ");
    $price_rules = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取价格策略列表失败：' . $e->getMessage();
    $price_rules = [];
}

// 判断是否显示表单
$show_form = false;
$edit_rule = null;

// 编辑价格策略时显示表单并获取价格策略信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT r.*, p.name as product_name, p.product_code
            FROM product_price_rules r
            JOIN product_items p ON r.product_id = p.id
            WHERE r.id = ?
        ");
        $stmt->execute([$edit_id]);
        $edit_rule = $stmt->fetch();
        if (!$edit_rule) {
            $error = '价格策略不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取价格策略信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加价格策略时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '价格策略添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '价格策略更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>价格策略管理</h2>
            <div class="breadcrumb">
                <a href="index.php">产品管理</a> &gt; 价格策略管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="price.php?action=add" class="btn btn-add">添加价格策略</a>
            </div>

            <!-- 添加/编辑价格策略表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_rule ? '编辑价格策略' : '添加价格策略'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_rule ? 'edit' : 'add'; ?>">
                        <?php if ($edit_rule): ?>
                            <input type="hidden" name="rule_id" value="<?php echo $edit_rule['id']; ?>">
                            <input type="hidden" name="product_id" value="<?php echo $edit_rule['product_id']; ?>">
                        <?php endif; ?>

                        <?php if ($edit_rule): ?>
                            <div class="form-group">
                                <label>产品名称：</label>
                                <div class="form-static"><?php echo htmlspecialchars($edit_rule['product_name']); ?> (<?php echo htmlspecialchars($edit_rule['product_code']); ?>)</div>
                            </div>
                        <?php else: ?>
                            <div class="form-group">
                                <label for="product_id">关联产品：</label>
                                <select id="product_id" name="product_id" required>
                                    <option value="">请选择产品</option>
                                    <?php foreach ($products as $product): ?>
                                        <option value="<?php echo $product['id']; ?>">
                                            <?php echo htmlspecialchars($product['name']); ?> (<?php echo htmlspecialchars($product['product_code']); ?>) - 标准价格: <?php echo number_format($product['price'], 2); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="rule_name">策略名称：</label>
                            <input type="text" id="rule_name" name="rule_name" value="<?php echo $edit_rule ? htmlspecialchars($edit_rule['rule_name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="client_level">客户级别：</label>
                            <select id="client_level" name="client_level">
                                <option value="" <?php echo ($edit_rule && $edit_rule['client_level'] === null) ? 'selected' : ''; ?>>不限制级别</option>
                                <option value="1" <?php echo ($edit_rule && $edit_rule['client_level'] === 1) ? 'selected' : ''; ?>>VIP客户</option>
                                <option value="2" <?php echo ($edit_rule && $edit_rule['client_level'] === 2) ? 'selected' : ''; ?>>普通客户</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="discount">折扣率(%)：</label>
                            <input type="number" id="discount" name="discount" min="0.01" max="100" step="0.01" value="<?php echo $edit_rule ? htmlspecialchars($edit_rule['discount']) : ''; ?>" required>
                            <small>输入0-100之间的数字，如80表示8折（原价的80%）</small>
                        </div>

                        <div class="form-group">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $edit_rule ? htmlspecialchars($edit_rule['start_date']) : ''; ?>">
                            <small>留空表示不限制开始日期</small>
                        </div>

                        <div class="form-group">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $edit_rule ? htmlspecialchars($edit_rule['end_date']) : ''; ?>">
                            <small>留空表示不限制结束日期</small>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_rule && $edit_rule['status'] == 1) ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo ($edit_rule && $edit_rule['status'] == 0) ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="price.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 价格策略列表 -->
            <div class="table-container">
                <h3>价格策略列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>产品编码</th>
                            <th>产品名称</th>
                            <th>策略名称</th>
                            <th>客户级别</th>
                            <th>折扣率</th>
                            <th>折后价</th>
                            <th>有效期</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($price_rules)): ?>
                            <tr>
                                <td colspan="11" class="text-center">暂无价格策略数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($price_rules as $rule): ?>
                                <tr>
                                    <td><?php echo $rule['id']; ?></td>
                                    <td><?php echo htmlspecialchars($rule['product_code']); ?></td>
                                    <td><?php echo htmlspecialchars($rule['product_name']); ?></td>
                                    <td><?php echo htmlspecialchars($rule['rule_name']); ?></td>
                                    <td>
                                        <?php
                                        if ($rule['client_level'] === null) echo '不限';
                                        elseif ($rule['client_level'] == 1) echo 'VIP客户';
                                        elseif ($rule['client_level'] == 2) echo '普通客户';
                                        ?>
                                    </td>
                                    <td><?php echo $rule['discount']; ?>%</td>
                                    <td><?php echo number_format($rule['standard_price'] * $rule['discount'] / 100, 2); ?></td>
                                    <td>
                                        <?php
                                        if (empty($rule['start_date']) && empty($rule['end_date'])) {
                                            echo '不限时间';
                                        } else {
                                            echo (!empty($rule['start_date']) ? $rule['start_date'] : '不限') . ' 至 ' . (!empty($rule['end_date']) ? $rule['end_date'] : '不限');
                                        }
                                        ?>
                                    </td>
                                    <td>
                                        <?php if ($rule['status'] == 1): ?>
                                            <span class="status-active">启用</span>
                                        <?php else: ?>
                                            <span class="status-inactive">禁用</span>
                                        <?php endif; ?>
                                    </td>
                                    <td><?php echo $rule['create_time']; ?></td>
                                    <td>
                                        <a href="price.php?action=edit&id=<?php echo $rule['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="rule_id" value="<?php echo $rule['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除价格策略 \'<?php echo htmlspecialchars($rule['rule_name']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>