<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('report_custom');

// 记录访问日志
record_log('访问自定义报表页面');

// 获取所有可用的报表模板
try {
    $stmt = $pdo->prepare("
        SELECT * FROM report_templates 
        WHERE 1=1
        ORDER BY category, name
    ");
    $stmt->execute();
    $templates = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取报表模板失败：' . $e->getMessage();
    $templates = [];
}

// 获取报表分类信息
$categories = [
    1 => '客户分析',
    2 => '销售分析',
    3 => '营销分析',
    4 => '满意度分析',
    5 => '财务分析'
];

// 处理模板筛选
$category_filter = isset($_GET['category']) ? intval($_GET['category']) : 0;
if ($category_filter > 0) {
    $filtered_templates = [];
    foreach ($templates as $template) {
        if ($template['category'] == $category_filter) {
            $filtered_templates[] = $template;
        }
    }
    $templates = $filtered_templates;
}

// 生成/导出报表处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 生成报表
    if ($_POST['action'] == 'generate') {
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $template_id = isset($_POST['template_id']) ? intval($_POST['template_id']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $params = isset($_POST['params']) ? $_POST['params'] : [];

        if (empty($title) || $template_id <= 0) {
            $error = '请填写报表标题并选择报表模板！';
        } else {
            try {
                // 获取选择的报表模板
                $stmt = $pdo->prepare("SELECT * FROM report_templates WHERE id = ?");
                $stmt->execute([$template_id]);
                $template = $stmt->fetch();

                if (!$template) {
                    $error = '找不到所选报表模板！';
                } else {
                    // 构建查询参数
                    $param_json = json_encode(array_merge($params, [
                        'start_date' => $start_date,
                        'end_date' => $end_date
                    ]));

                    // 生成报表文件名（确保使用.csv扩展名）
                    $file_name = '自定义报表_' . date('YmdHis') . '.csv';

                    // 确保reports目录存在
                    $reports_dir = __DIR__ . '/reports'; // 绝对路径
                    if (!is_dir($reports_dir)) {
                        if (!mkdir($reports_dir, 0755, true)) {
                            $error = '无法创建报表目录！';
                            throw new Exception('无法创建报表目录！');
                        }
                    }

                    // 完整的物理路径
                    $file_path = $reports_dir . '/' . $file_name;

                    // 数据库中存储的Web访问路径
                    $web_file_path = 'report/reports/' . $file_name;

                    // 根据模板SQL获取数据
                    $sql = $template['sql_content'];

                    // 替换SQL中的参数占位符
                    if (!empty($start_date)) {
                        $sql = str_replace('{start_date}', $start_date, $sql);
                    }

                    if (!empty($end_date)) {
                        $sql = str_replace('{end_date}', $end_date, $sql);
                    }

                    // 替换其他自定义参数
                    foreach ($params as $key => $value) {
                        if (!empty($value)) {
                            $sql = str_replace('{' . $key . '}', $value, $sql);
                        }
                    }

                    // 执行查询获取数据
                    $stmt = $pdo->prepare($sql);
                    $stmt->execute();
                    $report_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

                    if (empty($report_data)) {
                        $warning = '查询结果为空，请调整查询条件。';
                    }

                    // 创建并写入CSV文件
                    $file = fopen($file_path, 'w');

                    // 写入BOM头，确保Excel正确显示中文
                    fputs($file, "\xEF\xBB\xBF");

                    // 写入标题
                    fputcsv($file, [$title]);
                    fputcsv($file, ['报表类型：' . $categories[$template['category']] . ' - ' . $template['name']]);
                    fputcsv($file, ['报表生成时间：' . date('Y-m-d H:i:s')]);
                    if (!empty($start_date) && !empty($end_date)) {
                        fputcsv($file, ['统计时间范围：' . $start_date . ' 至 ' . $end_date]);
                    }
                    fputcsv($file, []);  // 空行

                    // 如果有数据则写入
                    if (!empty($report_data)) {
                        // 写入表头
                        $headers = array_keys($report_data[0]);
                        fputcsv($file, $headers);

                        // 写入数据行
                        foreach ($report_data as $row) {
                            fputcsv($file, $row);
                        }
                    } else {
                        fputcsv($file, ['无符合条件的数据']);
                    }

                    fclose($file);

                    // 添加报表记录
                    $stmt = $pdo->prepare("INSERT INTO report_records (template_id, title, params, file_path, creator_id) VALUES (?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$template_id, $title, $param_json, $web_file_path, $_SESSION['user_id']]);

                    if ($result) {
                        record_log("生成自定义报表：{$title}");
                        $success = '报表生成成功！';
                    } else {
                        $error = '报表生成失败！';
                    }
                }
            } catch (Exception $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 预览报表数据
    if ($_POST['action'] == 'preview') {
        $template_id = isset($_POST['template_id']) ? intval($_POST['template_id']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $params = isset($_POST['params']) ? $_POST['params'] : [];

        if ($template_id <= 0) {
            $preview_error = '请选择报表模板！';
        } else {
            try {
                // 获取选择的报表模板
                $stmt = $pdo->prepare("SELECT * FROM report_templates WHERE id = ?");
                $stmt->execute([$template_id]);
                $template = $stmt->fetch();

                if (!$template) {
                    $preview_error = '找不到所选报表模板！';
                } else {
                    // 根据模板SQL获取数据
                    $sql = $template['sql_content'];

                    // 替换SQL中的参数占位符
                    if (!empty($start_date)) {
                        $sql = str_replace('{start_date}', $start_date, $sql);
                    }

                    if (!empty($end_date)) {
                        $sql = str_replace('{end_date}', $end_date, $sql);
                    }

                    // 替换其他自定义参数
                    foreach ($params as $key => $value) {
                        if (!empty($value)) {
                            $sql = str_replace('{' . $key . '}', $value, $sql);
                        }
                    }

                    // 执行查询获取数据
                    $stmt = $pdo->prepare($sql);
                    $stmt->execute();
                    $preview_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

                    if (empty($preview_data)) {
                        $preview_warning = '查询结果为空，请调整查询条件。';
                    }
                }
            } catch (Exception $e) {
                $preview_error = '预览报表数据失败：' . $e->getMessage();
            }
        }
    }
}

// 获取最近生成的自定义报表
try {
    $stmt = $pdo->query("
        SELECT r.*, t.name as template_name, t.category, u.username 
        FROM report_records r
        JOIN report_templates t ON r.template_id = t.id 
        JOIN sys_users u ON r.creator_id = u.id 
        ORDER BY r.create_time DESC
        LIMIT 10
    ");
    $reports = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取报表记录失败：' . $e->getMessage();
    $reports = [];
}

// 获取用户自定义的报表模板
try {
    $stmt = $pdo->prepare("
        SELECT * FROM report_templates 
        WHERE is_system = 0 AND creator_id = ?
        ORDER BY create_time DESC
    ");
    $stmt->execute([$_SESSION['user_id']]);
    $user_templates = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取用户自定义模板失败：' . $e->getMessage();
    $user_templates = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>自定义报表</h2>
            <div class="breadcrumb">
                <a href="index.php">数据分析与报表</a> &gt; 自定义报表
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <?php if (isset($warning)): ?>
                <div class="alert" style="background-color: #fff3cd; color: #856404; border: 1px solid #ffeeba;">
                    <?php echo $warning; ?>
                </div>
            <?php endif; ?>

            <!-- 模板选择与筛选 -->
            <div class="filter-form">
                <h3>报表模板筛选</h3>
                <form method="get" action="">
                    <div class="form-group">
                        <label for="category">报表分类：</label>
                        <select id="category" name="category">
                            <option value="0">全部分类</option>
                            <?php foreach ($categories as $id => $name): ?>
                                <option value="<?php echo $id; ?>" <?php echo $category_filter == $id ? 'selected' : ''; ?>>
                                    <?php echo $name; ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">筛选</button>
                    </div>
                </form>
            </div>

            <!-- 生成报表 -->
            <div class="form-container">
                <h3>生成自定义报表</h3>
                <form method="post" action="" id="reportForm">
                    <input type="hidden" name="action" value="generate" id="formAction">

                    <div class="form-group">
                        <label for="title">报表标题：</label>
                        <input type="text" id="title" name="title" value="自定义报表 <?php echo date('Y-m-d'); ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="template_id">选择报表模板：</label>
                        <select id="template_id" name="template_id" required>
                            <option value="">-- 请选择报表模板 --</option>
                            <optgroup label="系统报表模板">
                                <?php foreach ($templates as $template): ?>
                                    <?php if ($template['is_system'] == 1): ?>
                                        <option value="<?php echo $template['id']; ?>" data-description="<?php echo htmlspecialchars($template['description']); ?>">
                                            [<?php echo $categories[$template['category']]; ?>] <?php echo $template['name']; ?>
                                        </option>
                                    <?php endif; ?>
                                <?php endforeach; ?>
                            </optgroup>

                            <?php if (!empty($user_templates)): ?>
                                <optgroup label="我的自定义模板">
                                    <?php foreach ($user_templates as $template): ?>
                                        <option value="<?php echo $template['id']; ?>" data-description="<?php echo htmlspecialchars($template['description']); ?>">
                                            [<?php echo $categories[$template['category']]; ?>] <?php echo $template['name']; ?>
                                        </option>
                                    <?php endforeach; ?>
                                </optgroup>
                            <?php endif; ?>
                        </select>
                    </div>

                    <div id="template_description" style="margin-bottom: 15px; padding: 10px; background-color: #f8f9fa; border: 1px solid #ddd; border-radius: 4px; display: none;"></div>

                    <div class="form-group">
                        <label for="start_date">开始日期：</label>
                        <input type="date" id="start_date" name="start_date" value="<?php echo date('Y-m-d', strtotime('-6 months')); ?>">
                    </div>

                    <div class="form-group">
                        <label for="end_date">结束日期：</label>
                        <input type="date" id="end_date" name="end_date" value="<?php echo date('Y-m-d'); ?>">
                    </div>

                    <!-- 常用参数 -->
                    <div class="form-group">
                        <label for="params[user_id]">用户ID：</label>
                        <input type="text" id="params[user_id]" name="params[user_id]" placeholder="输入用户ID（可选）">
                    </div>

                    <div class="form-group">
                        <label for="params[client_id]">客户ID：</label>
                        <input type="text" id="params[client_id]" name="params[client_id]" placeholder="输入客户ID（可选）">
                    </div>

                    <div class="form-group">
                        <label for="params[min_amount]">最小金额：</label>
                        <input type="number" id="params[min_amount]" name="params[min_amount]" placeholder="输入最小金额（可选）" step="0.01">
                    </div>

                    <div class="form-actions">
                        <button type="button" class="btn btn-secondary" onclick="previewReport()">预览数据</button>
                        <button type="submit" class="btn btn-success">生成报表</button>
                    </div>
                </form>
            </div>

            <!-- 预览数据 -->
            <?php if (isset($preview_data) && !isset($preview_error)): ?>
                <div class="section">
                    <h3>报表数据预览</h3>
                    <?php if (isset($preview_warning)): ?>
                        <div class="alert" style="background-color: #fff3cd; color: #856404; border: 1px solid #ffeeba;">
                            <?php echo $preview_warning; ?>
                        </div>
                    <?php endif; ?>

                    <?php if (!empty($preview_data)): ?>
                        <div class="table-responsive" style="max-height: 400px; overflow-y: auto;">
                            <table class="data-table">
                                <thead>
                                    <tr>
                                        <?php foreach (array_keys($preview_data[0]) as $header): ?>
                                            <th><?php echo htmlspecialchars($header); ?></th>
                                        <?php endforeach; ?>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($preview_data as $row): ?>
                                        <tr>
                                            <?php foreach ($row as $value): ?>
                                                <td><?php echo htmlspecialchars($value); ?></td>
                                            <?php endforeach; ?>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                        <p class="text-center">注：最多显示前100条记录的预览。</p>
                    <?php endif; ?>
                </div>
            <?php elseif (isset($preview_error)): ?>
                <div class="alert alert-danger"><?php echo $preview_error; ?></div>
            <?php endif; ?>

            <!-- 历史报表 -->
            <div class="table-container">
                <h3>最近生成的报表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>报表标题</th>
                            <th>报表类型</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($reports)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无报表记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($reports as $report): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($report['title']); ?></td>
                                    <td>
                                        <?php
                                        if (isset($categories[$report['category']])) {
                                            echo $categories[$report['category']] . ' - ';
                                        }
                                        echo htmlspecialchars($report['template_name']);
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($report['username']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($report['create_time'])); ?></td>
                                    <td>
                                        <a href="generate_report.php?id=<?php echo $report['id']; ?>" class="btn btn-sm btn-primary">下载</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分析说明 -->
            <div class="info-box">
                <h3>关于自定义报表</h3>
                <p>自定义报表功能允许您：</p>
                <ul>
                    <li><strong>选择报表模板</strong>：系统提供多种预定义的报表模板，涵盖客户、销售、营销等多个维度。</li>
                    <li><strong>设置查询参数</strong>：根据您的需求设置时间范围和其他筛选条件。</li>
                    <li><strong>预览报表数据</strong>：在生成报表前，可以预览数据内容。</li>
                    <li><strong>导出为CSV格式</strong>：生成的报表可以下载为CSV格式，方便在Excel中进一步分析。</li>
                </ul>
                <p>定期生成并分析报表数据，可以帮助您及时了解业务情况，为决策提供数据支持。</p>
            </div>
        </div>
    </div>

    <script>
        // 显示模板描述
        document.getElementById('template_id').addEventListener('change', function() {
            var selectedOption = this.options[this.selectedIndex];
            var description = selectedOption.getAttribute('data-description');
            var descriptionBox = document.getElementById('template_description');

            if (description && description.trim() !== '') {
                descriptionBox.textContent = '描述：' + description;
                descriptionBox.style.display = 'block';
            } else {
                descriptionBox.style.display = 'none';
            }
        });

        // 预览报表数据
        function previewReport() {
            document.getElementById('formAction').value = 'preview';
            document.getElementById('reportForm').submit();
        }
    </script>
</body>

</html>