<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('report_sales');

// 记录访问日志
record_log('访问销售业绩分析页面');

// 获取分析数据的时间范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-6 months'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 生成/导出报表处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 生成报表
    if ($_POST['action'] == 'generate') {
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $report_type = isset($_POST['report_type']) ? intval($_POST['report_type']) : 1;

        if (empty($title) || empty($start_date) || empty($end_date)) {
            $error = '请填写完整的报表信息！';
        } else {
            try {
                // 获取销售业绩分析模板
                $stmt = $pdo->prepare("SELECT id FROM report_templates WHERE category = 2 AND name LIKE '%销售业绩%' LIMIT 1");
                $stmt->execute();
                $template = $stmt->fetch();

                if (!$template) {
                    $error = '找不到销售业绩分析模板！';
                } else {
                    // 构建查询参数
                    $params = json_encode([
                        'start_date' => $start_date,
                        'end_date' => $end_date,
                        'report_type' => $report_type
                    ]);

                    // 生成报表文件名（确保使用.csv扩展名）
                    $file_name = '销售业绩分析_' . date('YmdHis') . '.csv';

                    // 确保reports目录存在
                    $reports_dir = __DIR__ . '/reports'; // 绝对路径
                    if (!is_dir($reports_dir)) {
                        if (!mkdir($reports_dir, 0755, true)) {
                            $error = '无法创建报表目录！';
                            throw new Exception('无法创建报表目录！');
                        }
                    }

                    // 完整的物理路径
                    $file_path = $reports_dir . '/' . $file_name;

                    // 数据库中存储的Web访问路径 - 修改为使用相对于网站根目录的路径
                    $web_file_path = 'report/reports/' . $file_name; // 关键修改：添加report/前缀

                    // 根据报表类型获取相应的数据
                    if ($report_type == 1 || $report_type == 3) {
                        // 获取月度销售额趋势
                        $stmt = $pdo->prepare("
                            SELECT 
                                DATE_FORMAT(create_time, '%Y-%m') as month, 
                                SUM(amount) as total_sales 
                            FROM order_orders 
                            WHERE status > 1 AND create_time BETWEEN ? AND ? 
                            GROUP BY month 
                            ORDER BY month
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $monthly_data = $stmt->fetchAll();
                    }

                    if ($report_type == 1 || $report_type == 2) {
                        // 获取销售人员业绩排名
                        $stmt = $pdo->prepare("
                            SELECT 
                                u.username as salesperson_name,
                                COUNT(o.id) as order_count,
                                SUM(o.amount) as total_amount
                            FROM order_orders o
                            JOIN sys_users u ON o.creator_id = u.id
                            WHERE o.status > 1 AND o.create_time BETWEEN ? AND ? 
                            GROUP BY o.creator_id
                            ORDER BY total_amount DESC
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $salesperson_data = $stmt->fetchAll();

                        // 获取产品销售情况
                        $stmt = $pdo->prepare("
                            SELECT 
                                p.name as product_name,
                                COUNT(*) as sale_count,
                                SUM(o.amount) as total_amount
                            FROM order_orders o
                            JOIN product_items p ON o.id = p.id  -- 这里假设有关联关系，实际可能需要通过订单明细表关联
                            WHERE o.status > 1 AND o.create_time BETWEEN ? AND ? 
                            GROUP BY p.id
                            ORDER BY total_amount DESC
                            LIMIT 10
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $product_data = $stmt->fetchAll();

                        // 获取销售线索转化情况
                        $stmt = $pdo->prepare("
                            SELECT 
                                CASE 
                                    WHEN stage = 1 THEN '新建'
                                    WHEN stage = 2 THEN '跟进中'
                                    WHEN stage = 3 THEN '报价'
                                    WHEN stage = 4 THEN '赢单'
                                    WHEN stage = 5 THEN '输单'
                                    ELSE '其他'
                                END as stage_name,
                                COUNT(*) as count
                            FROM sales_leads 
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY stage
                            ORDER BY stage
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $lead_stage_data = $stmt->fetchAll();
                    }

                    // 创建并写入CSV文件
                    $file = fopen($file_path, 'w');

                    // 写入BOM头，确保Excel正确显示中文
                    fputs($file, "\xEF\xBB\xBF");

                    // 写入标题
                    fputcsv($file, [$title]);
                    fputcsv($file, ['报表生成时间：' . date('Y-m-d H:i:s')]);
                    fputcsv($file, ['统计时间范围：' . $start_date . ' 至 ' . $end_date]);
                    fputcsv($file, []);  // 空行

                    // 写入月度趋势数据
                    if ($report_type == 1 || $report_type == 3) {
                        fputcsv($file, ['月度销售额趋势']);
                        fputcsv($file, ['月份', '销售总额']);
                        foreach ($monthly_data as $row) {
                            fputcsv($file, [$row['month'], $row['total_sales']]);
                        }
                        fputcsv($file, []);  // 空行
                    }

                    // 写入销售人员业绩
                    if ($report_type == 1 || $report_type == 2) {
                        fputcsv($file, ['销售人员业绩排名']);
                        fputcsv($file, ['销售人员', '订单数量', '销售金额', '占比']);
                        $total = 0;
                        foreach ($salesperson_data as $person) {
                            $total += $person['total_amount'];
                        }
                        foreach ($salesperson_data as $person) {
                            $percentage = $total > 0 ? round(($person['total_amount'] / $total) * 100, 2) : 0;
                            fputcsv($file, [$person['salesperson_name'], $person['order_count'], $person['total_amount'], $percentage . '%']);
                        }
                        fputcsv($file, []);  // 空行

                        // 写入产品销售情况
                        fputcsv($file, ['热销产品排名（Top 10）']);
                        fputcsv($file, ['产品名称', '销售数量', '销售金额', '占比']);
                        $total = 0;
                        foreach ($product_data as $product) {
                            $total += $product['total_amount'];
                        }
                        foreach ($product_data as $product) {
                            $percentage = $total > 0 ? round(($product['total_amount'] / $total) * 100, 2) : 0;
                            fputcsv($file, [$product['product_name'], $product['sale_count'], $product['total_amount'], $percentage . '%']);
                        }
                        fputcsv($file, []);  // 空行

                        // 写入销售线索阶段分布
                        fputcsv($file, ['销售线索阶段分布']);
                        fputcsv($file, ['阶段', '数量', '占比']);
                        $total = 0;
                        foreach ($lead_stage_data as $stage) {
                            $total += $stage['count'];
                        }
                        foreach ($lead_stage_data as $stage) {
                            $percentage = $total > 0 ? round(($stage['count'] / $total) * 100, 2) : 0;
                            fputcsv($file, [$stage['stage_name'], $stage['count'], $percentage . '%']);
                        }
                    }

                    fclose($file);

                    // 添加报表记录
                    $stmt = $pdo->prepare("INSERT INTO report_records (template_id, title, params, file_path, creator_id) VALUES (?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$template['id'], $title, $params, $web_file_path, $_SESSION['user_id']]);

                    if ($result) {
                        record_log("生成销售业绩分析报表：{$title}");
                        $success = '报表生成成功！';
                    } else {
                        $error = '报表生成失败！';
                    }
                }
            } catch (Exception $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取月度销售额趋势
try {
    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(create_time, '%Y-%m') as month, 
            SUM(amount) as total_sales 
        FROM order_orders 
        WHERE status > 1 AND create_time BETWEEN ? AND ? 
        GROUP BY month 
        ORDER BY month
    ");
    $stmt->execute([$start_date, $end_date]);
    $monthly_sales = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取月度销售额趋势数据失败：' . $e->getMessage();
    $monthly_sales = [];
}

// 获取销售人员业绩排名
try {
    $stmt = $pdo->prepare("
        SELECT 
            u.username as salesperson_name,
            COUNT(o.id) as order_count,
            SUM(o.amount) as total_amount
        FROM order_orders o
        JOIN sys_users u ON o.creator_id = u.id
        WHERE o.status > 1 AND o.create_time BETWEEN ? AND ? 
        GROUP BY o.creator_id
        ORDER BY total_amount DESC
    ");
    $stmt->execute([$start_date, $end_date]);
    $salesperson_ranking = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售人员业绩排名数据失败：' . $e->getMessage();
    $salesperson_ranking = [];
}

// 获取产品销售情况
try {
    $stmt = $pdo->prepare("
        SELECT 
            p.name as product_name,
            COUNT(*) as sale_count,
            SUM(o.amount) as total_amount
        FROM order_orders o
        JOIN product_items p ON o.id = p.id  -- 这里假设有关联关系，实际可能需要通过订单明细表关联
        WHERE o.status > 1 AND o.create_time BETWEEN ? AND ? 
        GROUP BY p.id
        ORDER BY total_amount DESC
        LIMIT 10
    ");
    $stmt->execute([$start_date, $end_date]);
    $product_sales = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取产品销售情况数据失败：' . $e->getMessage();
    $product_sales = [];
}

// 获取销售线索阶段分布
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE 
                WHEN stage = 1 THEN '新建'
                WHEN stage = 2 THEN '跟进中'
                WHEN stage = 3 THEN '报价'
                WHEN stage = 4 THEN '赢单'
                WHEN stage = 5 THEN '输单'
                ELSE '其他'
            END as stage_name,
            COUNT(*) as count
        FROM sales_leads 
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY stage
        ORDER BY stage
    ");
    $stmt->execute([$start_date, $end_date]);
    $lead_stage_distribution = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售线索阶段分布数据失败：' . $e->getMessage();
    $lead_stage_distribution = [];
}

// 获取最近生成的销售业绩分析报表
try {
    $stmt = $pdo->query("
        SELECT r.*, t.name as template_name, u.username 
        FROM report_records r
        JOIN report_templates t ON r.template_id = t.id 
        JOIN sys_users u ON r.creator_id = u.id 
        WHERE t.category = 2 AND t.name LIKE '%销售业绩%'
        ORDER BY r.create_time DESC
        LIMIT 5
    ");
    $reports = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取报表记录失败：' . $e->getMessage();
    $reports = [];
}

// 计算统计数据
$total_sales = 0;
foreach ($monthly_sales as $month) {
    $total_sales += $month['total_sales'];
}

// 计算平均月度销售额
$month_count = count($monthly_sales);
$avg_monthly_sales = $month_count > 0 ? round($total_sales / $month_count, 2) : 0;

// 计算销售线索转化率
$total_leads = 0;
$won_leads = 0;
foreach ($lead_stage_distribution as $stage) {
    $total_leads += $stage['count'];
    if ($stage['stage_name'] == '赢单') {
        $won_leads = $stage['count'];
    }
}
$conversion_rate = $total_leads > 0 ? round(($won_leads / $total_leads) * 100, 2) : 0;
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>销售业绩分析</h2>
            <div class="breadcrumb">
                <a href="index.php">数据分析与报表</a> &gt; 销售业绩分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="form-group">
                        <label for="start_date">开始日期：</label>
                        <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                    </div>

                    <div class="form-group">
                        <label for="end_date">结束日期：</label>
                        <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">查询</button>
                    </div>
                </form>
            </div>

            <!-- 统计概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>总销售额</h3>
                    <div class="number"><?php echo number_format($total_sales, 2); ?></div>
                    <div class="desc">所选时间范围内销售总额</div>
                </div>

                <div class="dashboard-card">
                    <h3>平均月度销售额</h3>
                    <div class="number"><?php echo number_format($avg_monthly_sales, 2); ?></div>
                    <div class="desc">每月平均销售额</div>
                </div>

                <div class="dashboard-card">
                    <h3>销售线索转化率</h3>
                    <div class="number"><?php echo $conversion_rate; ?>%</div>
                    <div class="desc">销售线索转化为成交的比率</div>
                </div>
            </div>

            <!-- 月度销售趋势 -->
            <div class="section">
                <h3>月度销售额趋势</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>月份</th>
                            <th>销售总额</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($monthly_sales)): ?>
                            <tr>
                                <td colspan="2" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($monthly_sales as $month): ?>
                                <tr>
                                    <td><?php echo $month['month']; ?></td>
                                    <td><?php echo number_format($month['total_sales'], 2); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 销售人员业绩排名 -->
            <div class="section">
                <h3>销售人员业绩排名</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>销售人员</th>
                            <th>订单数量</th>
                            <th>销售金额</th>
                            <th>占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($salesperson_ranking)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total = 0;
                            foreach ($salesperson_ranking as $person) {
                                $total += $person['total_amount'];
                            }
                            foreach ($salesperson_ranking as $person):
                                $percentage = $total > 0 ? round(($person['total_amount'] / $total) * 100, 2) : 0;
                            ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($person['salesperson_name']); ?></td>
                                    <td><?php echo $person['order_count']; ?></td>
                                    <td><?php echo number_format($person['total_amount'], 2); ?></td>
                                    <td><?php echo $percentage; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 热销产品排名 -->
            <div class="section">
                <h3>热销产品排名（Top 10）</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>产品名称</th>
                            <th>销售数量</th>
                            <th>销售金额</th>
                            <th>占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($product_sales)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total = 0;
                            foreach ($product_sales as $product) {
                                $total += $product['total_amount'];
                            }
                            foreach ($product_sales as $product):
                                $percentage = $total > 0 ? round(($product['total_amount'] / $total) * 100, 2) : 0;
                            ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($product['product_name']); ?></td>
                                    <td><?php echo $product['sale_count']; ?></td>
                                    <td><?php echo number_format($product['total_amount'], 2); ?></td>
                                    <td><?php echo $percentage; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 销售线索阶段分布 -->
            <div class="section">
                <h3>销售线索阶段分布</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>阶段</th>
                            <th>数量</th>
                            <th>占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($lead_stage_distribution)): ?>
                            <tr>
                                <td colspan="3" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total = 0;
                            foreach ($lead_stage_distribution as $stage) {
                                $total += $stage['count'];
                            }
                            foreach ($lead_stage_distribution as $stage):
                                $percentage = $total > 0 ? round(($stage['count'] / $total) * 100, 2) : 0;
                            ?>
                                <tr>
                                    <td><?php echo $stage['stage_name']; ?></td>
                                    <td><?php echo $stage['count']; ?></td>
                                    <td><?php echo $percentage; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 生成报表 -->
            <div class="form-container">
                <h3>生成报表</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="generate">

                    <div class="form-group">
                        <label for="title">报表标题：</label>
                        <input type="text" id="title" name="title" value="销售业绩分析报表 <?php echo date('Y-m-d'); ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_start_date">统计开始日期：</label>
                        <input type="date" id="report_start_date" name="start_date" value="<?php echo $start_date; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_end_date">统计结束日期：</label>
                        <input type="date" id="report_end_date" name="end_date" value="<?php echo $end_date; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_type">报表类型：</label>
                        <select id="report_type" name="report_type">
                            <option value="1">完整报表（包含所有数据）</option>
                            <option value="2">业绩报表（侧重销售人员和产品）</option>
                            <option value="3">趋势报表（侧重销售趋势）</option>
                        </select>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">生成报表</button>
                    </div>
                </form>
            </div>

            <!-- 历史报表 -->
            <div class="table-container">
                <h3>历史报表记录</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>报表标题</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($reports)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无报表记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($reports as $report): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($report['title']); ?></td>
                                    <td><?php echo htmlspecialchars($report['username']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($report['create_time'])); ?></td>
                                    <td>
                                        <a href="generate_report.php?id=<?php echo $report['id']; ?>" class="btn btn-sm btn-primary">下载</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分析说明 -->
            <div class="info-box">
                <h3>关于销售业绩分析</h3>
                <p>销售业绩分析帮助您了解：</p>
                <ul>
                    <li><strong>销售趋势</strong>：监控销售额变化，发现增长或下降趋势。</li>
                    <li><strong>业绩排名</strong>：了解销售人员业绩情况，发现优秀销售和培训需求。</li>
                    <li><strong>产品表现</strong>：分析热销产品和滞销产品，调整产品策略。</li>
                    <li><strong>转化效率</strong>：评估销售线索转化率，优化销售流程。</li>
                </ul>
                <p>定期分析销售业绩数据，可以帮助您制定更有效的销售策略和团队管理计划。</p>
            </div>
        </div>
    </div>
</body>

</html>