<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('sales');

// 记录访问日志
record_log('访问销售管理页面');

// 获取销售线索和机会总数
try {
    $stmt = $pdo->query("SELECT 
                            SUM(CASE WHEN type = 1 THEN 1 ELSE 0 END) as clue_count,
                            SUM(CASE WHEN type = 2 THEN 1 ELSE 0 END) as chance_count
                         FROM sales_leads");
    $leads_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取销售线索/机会数据失败：' . $e->getMessage();
    $leads_count = ['clue_count' => 0, 'chance_count' => 0];
}

// 获取合同统计
try {
    $stmt = $pdo->query("SELECT 
                            COUNT(*) as count, 
                            SUM(CASE WHEN status = 3 THEN amount ELSE 0 END) as effective_amount
                         FROM sales_contracts");
    $contract_stats = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取合同数据失败：' . $e->getMessage();
    $contract_stats = ['count' => 0, 'effective_amount' => 0];
}

// 获取报价统计
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count, SUM(amount) as total_amount FROM sales_quotes");
    $quote_stats = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取报价数据失败：' . $e->getMessage();
    $quote_stats = ['count' => 0, 'total_amount' => 0];
}

// 获取当月销售目标和完成情况
$current_year = date('Y');
$current_month = date('n');
try {
    $stmt = $pdo->prepare("SELECT SUM(target_amount) as target, SUM(actual_amount) as actual
                           FROM sales_targets 
                           WHERE year = ? AND month = ?");
    $stmt->execute([$current_year, $current_month]);
    $target_stats = $stmt->fetch();

    if (!$target_stats || $target_stats['target'] == 0) {
        $completion_rate = 0;
    } else {
        $completion_rate = ($target_stats['actual'] / $target_stats['target']) * 100;
    }
} catch (PDOException $e) {
    $error = '获取销售目标数据失败：' . $e->getMessage();
    $target_stats = ['target' => 0, 'actual' => 0];
    $completion_rate = 0;
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>销售管理</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <h2>销售概览</h2>
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>销售线索</h3>
                    <div class="number"><?php echo $leads_count['clue_count']; ?></div>
                    <div class="desc">线索总数</div>
                </div>

                <div class="dashboard-card">
                    <h3>销售机会</h3>
                    <div class="number"><?php echo $leads_count['chance_count']; ?></div>
                    <div class="desc">机会总数</div>
                </div>

                <div class="dashboard-card">
                    <h3>合同总额</h3>
                    <div class="number"><?php echo number_format($contract_stats['effective_amount'] ?: 0, 2); ?></div>
                    <div class="desc">已生效合同金额</div>
                </div>

                <div class="dashboard-card">
                    <h3>本月目标完成率</h3>
                    <div class="number"><?php echo number_format($completion_rate, 2); ?>%</div>
                    <div class="desc"><?php echo number_format($target_stats['actual'], 2); ?>/<?php echo number_format($target_stats['target'], 2); ?></div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="chance.php" class="function-link">
                    <h3>销售机会管理</h3>
                </a>
                <a href="clue.php" class="function-link">
                    <h3>销售线索管理</h3>
                </a>
                <a href="track.php" class="function-link">
                    <h3>销售过程跟踪</h3>
                </a>                                
                <a href="contract.php" class="function-link">
                    <h3>合同管理</h3>
                </a>
                <a href="quote.php" class="function-link">
                    <h3>报价管理</h3>
                </a>
                <a href="target.php" class="function-link">
                    <h3>销售目标与绩效</h3>
                </a>
            </div>

            <h2>最近合同记录</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>合同编号</th>
                            <th>客户名称</th>
                            <th>金额</th>
                            <th>开始日期</th>
                            <th>结束日期</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT c.*, cl.client_name 
                                            FROM sales_contracts c
                                            JOIN crm_clients cl ON c.client_id = cl.id
                                            ORDER BY c.create_time DESC LIMIT 5");
                            $contracts = $stmt->fetchAll();

                            if (empty($contracts)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无合同记录</td>
                                </tr>
                                <?php else:
                                foreach ($contracts as $contract): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($contract['contract_no']); ?></td>
                                        <td><?php echo htmlspecialchars($contract['client_name']); ?></td>
                                        <td><?php echo number_format($contract['amount'], 2); ?></td>
                                        <td><?php echo $contract['start_date']; ?></td>
                                        <td><?php echo $contract['end_date']; ?></td>
                                        <td>
                                            <?php
                                            if ($contract['status'] == 1) echo '<span class="status-pending">草稿</span>';
                                            elseif ($contract['status'] == 2) echo '<span class="status-pending">审核中</span>';
                                            elseif ($contract['status'] == 3) echo '<span class="status-active">已生效</span>';
                                            ?>
                                        </td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="6" class="text-center">获取合同记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>

            <h2>最近报价记录</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>报价单号</th>
                            <th>客户名称</th>
                            <th>金额</th>
                            <th>状态</th>
                            <th>创建时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT q.*, cl.client_name 
                                            FROM sales_quotes q
                                            JOIN crm_clients cl ON q.client_id = cl.id
                                            ORDER BY q.create_time DESC LIMIT 5");
                            $quotes = $stmt->fetchAll();

                            if (empty($quotes)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无报价记录</td>
                                </tr>
                                <?php else:
                                foreach ($quotes as $quote): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($quote['quote_no']); ?></td>
                                        <td><?php echo htmlspecialchars($quote['client_name']); ?></td>
                                        <td><?php echo number_format($quote['amount'], 2); ?></td>
                                        <td>
                                            <?php
                                            if ($quote['status'] == 1) echo '<span class="status-pending">草稿</span>';
                                            elseif ($quote['status'] == 2) echo '<span class="status-active">已发送</span>';
                                            elseif ($quote['status'] == 3) echo '<span class="status-active">已接受</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($quote['create_time'])); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="5" class="text-center">获取报价记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>