<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('sales_target');

// 记录访问日志
record_log('访问销售目标管理页面');

// 添加/编辑/删除销售目标处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加销售目标
    if ($_POST['action'] == 'add') {
        $user_id = isset($_POST['user_id']) ? intval($_POST['user_id']) : 0;
        $year = isset($_POST['year']) ? intval($_POST['year']) : date('Y');
        $month = isset($_POST['month']) ? intval($_POST['month']) : date('m');
        $target_amount = isset($_POST['target_amount']) ? floatval($_POST['target_amount']) : 0;
        $actual_amount = isset($_POST['actual_amount']) ? floatval($_POST['actual_amount']) : 0;

        if ($user_id <= 0 || $year < 2000 || $month < 1 || $month > 12 || $target_amount <= 0) {
            $error = '请填写完整销售目标信息！';
        } else {
            try {
                // 检查是否已存在同一用户的同年同月目标
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sales_targets WHERE user_id = ? AND year = ? AND month = ?");
                $stmt->execute([$user_id, $year, $month]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该销售人员当月目标已存在！';
                } else {
                    // 添加销售目标
                    $stmt = $pdo->prepare("INSERT INTO sales_targets (user_id, year, month, target_amount, actual_amount) VALUES (?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$user_id, $year, $month, $target_amount, $actual_amount]);

                    if ($result) {
                        // 获取用户名
                        $stmt = $pdo->prepare("SELECT username FROM sys_users WHERE id = ?");
                        $stmt->execute([$user_id]);
                        $user = $stmt->fetch();

                        record_log("添加销售目标：{$user['username']} {$year}年{$month}月 目标金额：{$target_amount}");
                        $success = '销售目标添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: target.php?success=add');
                        exit;
                    } else {
                        $error = '销售目标添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑销售目标
    elseif ($_POST['action'] == 'edit') {
        $target_id = isset($_POST['target_id']) ? intval($_POST['target_id']) : 0;
        $target_amount = isset($_POST['target_amount']) ? floatval($_POST['target_amount']) : 0;
        $actual_amount = isset($_POST['actual_amount']) ? floatval($_POST['actual_amount']) : 0;

        if ($target_id <= 0 || $target_amount <= 0) {
            $error = '请填写完整销售目标信息！';
        } else {
            try {
                // 更新销售目标
                $stmt = $pdo->prepare("UPDATE sales_targets SET target_amount = ?, actual_amount = ? WHERE id = ?");
                $result = $stmt->execute([$target_amount, $actual_amount, $target_id]);

                if ($result) {
                    // 获取目标详情，用于日志
                    $stmt = $pdo->prepare("
                        SELECT t.*, u.username 
                        FROM sales_targets t
                        JOIN sys_users u ON t.user_id = u.id
                        WHERE t.id = ?
                    ");
                    $stmt->execute([$target_id]);
                    $target = $stmt->fetch();

                    record_log("编辑销售目标：{$target['username']} {$target['year']}年{$target['month']}月 目标金额：{$target_amount}");
                    $success = '销售目标更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: target.php?success=edit');
                    exit;
                } else {
                    $error = '销售目标更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除销售目标
    elseif ($_POST['action'] == 'delete') {
        $target_id = isset($_POST['target_id']) ? intval($_POST['target_id']) : 0;

        if ($target_id <= 0) {
            $error = '无效的销售目标ID！';
        } else {
            try {
                // 获取目标详情，用于日志记录
                $stmt = $pdo->prepare("
                    SELECT t.*, u.username 
                    FROM sales_targets t
                    JOIN sys_users u ON t.user_id = u.id
                    WHERE t.id = ?
                ");
                $stmt->execute([$target_id]);
                $target = $stmt->fetch();

                if (!$target) {
                    $error = '销售目标不存在！';
                } else {
                    // 检查是否为将来的目标或当月目标（不应删除历史数据）
                    $today = date('Y-m');
                    $target_date = $target['year'] . '-' . str_pad($target['month'], 2, '0', STR_PAD_LEFT);

                    if ($target_date < $today) {
                        $error = '不能删除历史销售目标！';
                    } else {
                        // 删除销售目标
                        $stmt = $pdo->prepare("DELETE FROM sales_targets WHERE id = ?");
                        $result = $stmt->execute([$target_id]);

                        if ($result) {
                            record_log("删除销售目标：{$target['username']} {$target['year']}年{$target['month']}月");
                            $success = '销售目标删除成功！';
                        } else {
                            $error = '销售目标删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取当前年份和月份
$current_year = date('Y');
$current_month = date('m');

// 获取筛选参数
$filter_year = isset($_GET['year']) ? intval($_GET['year']) : $current_year;
$filter_month = isset($_GET['month']) ? intval($_GET['month']) : $current_month;

// 获取所有销售人员（用户）
try {
    $stmt = $pdo->query("SELECT id, username FROM sys_users WHERE status = 1 ORDER BY id");
    $users = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取用户列表失败：' . $e->getMessage();
    $users = [];
}

// 获取销售目标列表
try {
    $stmt = $pdo->prepare("
        SELECT t.*, 
               u.username, 
               u.status as user_status,
               IFNULL(t.actual_amount / t.target_amount * 100, 0) as completion_rate
        FROM sales_targets t
        JOIN sys_users u ON t.user_id = u.id
        WHERE t.year = ? AND t.month = ?
        ORDER BY completion_rate DESC, t.target_amount DESC
    ");
    $stmt->execute([$filter_year, $filter_month]);
    $targets = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售目标列表失败：' . $e->getMessage();
    $targets = [];
}

// 获取团队整体完成情况
try {
    $stmt = $pdo->prepare("
        SELECT 
            SUM(target_amount) as total_target,
            SUM(actual_amount) as total_actual,
            IFNULL(SUM(actual_amount) / SUM(target_amount) * 100, 0) as total_rate
        FROM sales_targets
        WHERE year = ? AND month = ?
    ");
    $stmt->execute([$filter_year, $filter_month]);
    $team_stats = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取团队统计数据失败：' . $e->getMessage();
    $team_stats = [
        'total_target' => 0,
        'total_actual' => 0,
        'total_rate' => 0
    ];
}

// 获取销售目标完成情况排名
try {
    $stmt = $pdo->prepare("
        SELECT 
            u.username,
            SUM(t.target_amount) as user_target,
            SUM(t.actual_amount) as user_actual,
            IFNULL(SUM(t.actual_amount) / SUM(t.target_amount) * 100, 0) as user_rate
        FROM sales_targets t
        JOIN sys_users u ON t.user_id = u.id
        WHERE t.year = ? AND t.month = ?
        GROUP BY t.user_id
        ORDER BY user_rate DESC
    ");
    $stmt->execute([$filter_year, $filter_month]);
    $rankings = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售排名数据失败：' . $e->getMessage();
    $rankings = [];
}

// 判断是否显示表单
$show_form = false;
$edit_target = null;

// 编辑销售目标时显示表单并获取目标信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT t.*, u.username 
            FROM sales_targets t 
            JOIN sys_users u ON t.user_id = u.id 
            WHERE t.id = ?
        ");
        $stmt->execute([$edit_id]);
        $edit_target = $stmt->fetch();
        if (!$edit_target) {
            $error = '销售目标不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取销售目标信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加销售目标时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '销售目标添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '销售目标更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>销售目标管理</h2>
            <div class="breadcrumb">
                <a href="index.php">销售管理</a> &gt; 销售目标管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 团队整体完成情况 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>团队月度目标</h3>
                    <div class="number"><?php echo number_format($team_stats['total_target'], 2); ?></div>
                    <div class="desc"><?php echo $filter_year; ?>年<?php echo $filter_month; ?>月目标金额</div>
                </div>

                <div class="dashboard-card">
                    <h3>团队实际业绩</h3>
                    <div class="number"><?php echo number_format($team_stats['total_actual'], 2); ?></div>
                    <div class="desc"><?php echo $filter_year; ?>年<?php echo $filter_month; ?>月实际金额</div>
                </div>

                <div class="dashboard-card">
                    <h3>团队目标完成率</h3>
                    <div class="number"><?php echo number_format($team_stats['total_rate'], 2); ?>%</div>
                    <div class="desc">
                        <?php
                        if ($team_stats['total_rate'] >= 100) echo '<span class="status-active">已超额完成</span>';
                        elseif ($team_stats['total_rate'] >= 80) echo '<span class="status-pending">接近完成</span>';
                        else echo '<span class="status-inactive">需要努力</span>';
                        ?>
                    </div>
                </div>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="year">年份：</label>
                            <select id="year" name="year">
                                <?php for ($i = $current_year - 2; $i <= $current_year + 1; $i++): ?>
                                    <option value="<?php echo $i; ?>" <?php echo ($i == $filter_year) ? 'selected' : ''; ?>><?php echo $i; ?>年</option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="month">月份：</label>
                            <select id="month" name="month">
                                <?php for ($i = 1; $i <= 12; $i++): ?>
                                    <option value="<?php echo $i; ?>" <?php echo ($i == $filter_month) ? 'selected' : ''; ?>><?php echo $i; ?>月</option>
                                <?php endfor; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="target.php?action=add" class="btn btn-add">添加销售目标</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 销售人员排名 -->
            <div class="table-container">
                <h3>销售业绩排名 (<?php echo $filter_year; ?>年<?php echo $filter_month; ?>月)</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>销售人员</th>
                            <th>月度目标</th>
                            <th>实际业绩</th>
                            <th>完成率</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($rankings)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无销售业绩排名数据</td>
                            </tr>
                        <?php else: ?>
                            <?php $rank = 1; ?>
                            <?php foreach ($rankings as $ranking): ?>
                                <tr>
                                    <td><?php echo $rank++; ?></td>
                                    <td><?php echo htmlspecialchars($ranking['username']); ?></td>
                                    <td><?php echo number_format($ranking['user_target'], 2); ?></td>
                                    <td><?php echo number_format($ranking['user_actual'], 2); ?></td>
                                    <td><?php echo number_format($ranking['user_rate'], 2); ?>%</td>
                                    <td>
                                        <?php
                                        if ($ranking['user_rate'] >= 100) echo '<span class="status-active">已完成</span>';
                                        elseif ($ranking['user_rate'] >= 80) echo '<span class="status-pending">接近完成</span>';
                                        else echo '<span class="status-inactive">需努力</span>';
                                        ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 添加/编辑销售目标表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_target ? '编辑销售目标' : '添加销售目标'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_target ? 'edit' : 'add'; ?>">
                        <?php if ($edit_target): ?>
                            <input type="hidden" name="target_id" value="<?php echo $edit_target['id']; ?>">
                        <?php endif; ?>

                        <?php if (!$edit_target): ?>
                            <div class="form-group">
                                <label for="user_id">销售人员：</label>
                                <select id="user_id" name="user_id" required>
                                    <option value="">请选择销售人员</option>
                                    <?php foreach ($users as $user): ?>
                                        <option value="<?php echo $user['id']; ?>"><?php echo htmlspecialchars($user['username']); ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="year">年份：</label>
                                <select id="year" name="year">
                                    <?php for ($i = $current_year - 1; $i <= $current_year + 1; $i++): ?>
                                        <option value="<?php echo $i; ?>" <?php echo ($i == $current_year) ? 'selected' : ''; ?>><?php echo $i; ?>年</option>
                                    <?php endfor; ?>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="month">月份：</label>
                                <select id="month" name="month">
                                    <?php for ($i = 1; $i <= 12; $i++): ?>
                                        <option value="<?php echo $i; ?>" <?php echo ($i == $current_month) ? 'selected' : ''; ?>><?php echo $i; ?>月</option>
                                    <?php endfor; ?>
                                </select>
                            </div>
                        <?php else: ?>
                            <div class="form-group">
                                <label>销售人员：</label>
                                <div class="form-static"><?php echo htmlspecialchars($edit_target['username']); ?></div>
                            </div>

                            <div class="form-group">
                                <label>年月：</label>
                                <div class="form-static"><?php echo $edit_target['year']; ?>年<?php echo $edit_target['month']; ?>月</div>
                            </div>
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="target_amount">目标金额：</label>
                            <input type="number" id="target_amount" name="target_amount" step="0.01" min="0" value="<?php echo $edit_target ? htmlspecialchars($edit_target['target_amount']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="actual_amount">实际金额：</label>
                            <input type="number" id="actual_amount" name="actual_amount" step="0.01" min="0" value="<?php echo $edit_target ? htmlspecialchars($edit_target['actual_amount']) : '0'; ?>">
                            <small>可以留空，系统会随着销售合同的完成自动更新</small>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="target.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 销售目标列表 -->
            <div class="table-container">
                <h3>销售目标列表 (<?php echo $filter_year; ?>年<?php echo $filter_month; ?>月)</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>销售人员</th>
                            <th>年月</th>
                            <th>目标金额</th>
                            <th>实际金额</th>
                            <th>完成率</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($targets)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无销售目标数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($targets as $target): ?>
                                <tr>
                                    <td><?php echo $target['id']; ?></td>
                                    <td><?php echo htmlspecialchars($target['username']); ?></td>
                                    <td><?php echo $target['year']; ?>年<?php echo $target['month']; ?>月</td>
                                    <td><?php echo number_format($target['target_amount'], 2); ?></td>
                                    <td><?php echo number_format($target['actual_amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        $rate = number_format($target['completion_rate'], 2);
                                        echo $rate . '%';
                                        if ($rate >= 100) {
                                            echo ' <span class="status-active">已完成</span>';
                                        } elseif ($rate >= 80) {
                                            echo ' <span class="status-pending">接近完成</span>';
                                        } else {
                                            echo ' <span class="status-inactive">需努力</span>';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($target['create_time'])); ?></td>
                                    <td>
                                        <a href="target.php?action=edit&id=<?php echo $target['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                        <?php
                                        // 只允许删除当月或未来月份的目标
                                        $target_date = $target['year'] . '-' . str_pad($target['month'], 2, '0', STR_PAD_LEFT);
                                        $today = date('Y-m');
                                        if ($target_date >= $today):
                                        ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="target_id" value="<?php echo $target['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除 <?php echo htmlspecialchars($target['username']); ?> <?php echo $target['year']; ?>年<?php echo $target['month']; ?>月 的销售目标吗？');">删除</button>
                                            </form>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>