<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('service_knowledge');

// 记录访问日志
record_log('访问知识库管理页面');

// 添加/编辑/删除知识库文章
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加知识库文章
    if ($_POST['action'] == 'add') {
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $category = isset($_POST['category']) ? intval($_POST['category']) : 1;

        if (empty($title) || empty($content)) {
            $error = '请填写完整的知识库信息！';
        } else {
            try {
                // 添加知识库文章
                $stmt = $pdo->prepare("INSERT INTO service_knowledge (title, content, category, create_user_id) VALUES (?, ?, ?, ?)");
                $result = $stmt->execute([$title, $content, $category, $_SESSION['user_id']]);

                if ($result) {
                    record_log("添加知识库文章：{$title}");
                    $success = '知识库文章添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: knowledge.php?success=add');
                    exit;
                } else {
                    $error = '知识库文章添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑知识库文章
    elseif ($_POST['action'] == 'edit') {
        $knowledge_id = isset($_POST['knowledge_id']) ? intval($_POST['knowledge_id']) : 0;
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $category = isset($_POST['category']) ? intval($_POST['category']) : 1;

        if ($knowledge_id <= 0 || empty($title) || empty($content)) {
            $error = '请填写完整的知识库信息！';
        } else {
            try {
                // 更新知识库文章
                $stmt = $pdo->prepare("UPDATE service_knowledge SET title = ?, content = ?, category = ? WHERE id = ?");
                $result = $stmt->execute([$title, $content, $category, $knowledge_id]);

                if ($result) {
                    record_log("编辑知识库文章：{$title}");
                    $success = '知识库文章更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: knowledge.php?success=edit');
                    exit;
                } else {
                    $error = '知识库文章更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除知识库文章
    elseif ($_POST['action'] == 'delete') {
        $knowledge_id = isset($_POST['knowledge_id']) ? intval($_POST['knowledge_id']) : 0;

        if ($knowledge_id <= 0) {
            $error = '无效的知识库文章ID！';
        } else {
            try {
                // 获取文章标题，用于日志记录
                $stmt = $pdo->prepare("SELECT title FROM service_knowledge WHERE id = ?");
                $stmt->execute([$knowledge_id]);
                $knowledge = $stmt->fetch();

                if (!$knowledge) {
                    $error = '知识库文章不存在！';
                } else {
                    // 删除知识库文章
                    $stmt = $pdo->prepare("DELETE FROM service_knowledge WHERE id = ?");
                    $result = $stmt->execute([$knowledge_id]);

                    if ($result) {
                        record_log("删除知识库文章：{$knowledge['title']}");
                        $success = '知识库文章删除成功！';
                    } else {
                        $error = '知识库文章删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取分类筛选参数
$category_filter = isset($_GET['category']) ? intval($_GET['category']) : 0;

// 构建筛选条件
$where_clause = '';
$params = [];

if ($category_filter > 0) {
    $where_clause = "WHERE category = ?";
    $params[] = $category_filter;
}

// 获取所有知识库文章
try {
    $sql = "SELECT k.*, u.username as creator_name 
            FROM service_knowledge k
            LEFT JOIN sys_users u ON k.create_user_id = u.id 
            {$where_clause}
            ORDER BY k.id DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $knowledge_articles = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取知识库文章列表失败：' . $e->getMessage();
    $knowledge_articles = [];
}

// 判断是否显示表单
$show_form = false;
$edit_knowledge = null;

// 编辑知识库文章时显示表单并获取文章信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM service_knowledge WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_knowledge = $stmt->fetch();
        if (!$edit_knowledge) {
            $error = '知识库文章不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取知识库文章信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加知识库文章时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '知识库文章添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '知识库文章更新成功！';
    }
}

// 统计各分类的知识库文章数量
$category_stats = [
    1 => 0, // 常见问题
    2 => 0, // 教程
    3 => 0  // 故障排除
];

foreach ($knowledge_articles as $article) {
    if (isset($category_stats[$article['category']])) {
        $category_stats[$article['category']]++;
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>知识库管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客户服务与售后</a> &gt; 知识库管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 知识库分类统计 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>常见问题</h3>
                    <div class="number"><?php echo $category_stats[1]; ?></div>
                    <div class="desc"><a href="?category=1">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>教程</h3>
                    <div class="number"><?php echo $category_stats[2]; ?></div>
                    <div class="desc"><a href="?category=2">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>故障排除</h3>
                    <div class="number"><?php echo $category_stats[3]; ?></div>
                    <div class="desc"><a href="?category=3">查看详情</a></div>
                </div>
            </div>

            <div class="action-bar">
                <a href="knowledge.php?action=add" class="btn btn-add">添加知识库文章</a>
                <a href="knowledge.php" class="btn btn-secondary">全部文章</a>
            </div>

            <!-- 添加/编辑知识库文章表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_knowledge ? '编辑知识库文章' : '添加知识库文章'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_knowledge ? 'edit' : 'add'; ?>">
                        <?php if ($edit_knowledge): ?>
                            <input type="hidden" name="knowledge_id" value="<?php echo $edit_knowledge['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="title">标题：</label>
                            <input type="text" id="title" name="title" value="<?php echo $edit_knowledge ? htmlspecialchars($edit_knowledge['title']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="category">分类：</label>
                            <select id="category" name="category">
                                <option value="1" <?php echo ($edit_knowledge && $edit_knowledge['category'] == 1) ? 'selected' : ''; ?>>常见问题</option>
                                <option value="2" <?php echo ($edit_knowledge && $edit_knowledge['category'] == 2) ? 'selected' : ''; ?>>教程</option>
                                <option value="3" <?php echo ($edit_knowledge && $edit_knowledge['category'] == 3) ? 'selected' : ''; ?>>故障排除</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="content">内容：</label>
                            <textarea id="content" name="content" rows="10" required><?php echo $edit_knowledge ? htmlspecialchars($edit_knowledge['content']) : ''; ?></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="knowledge.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 知识库文章列表 -->
            <div class="table-container">
                <h3>知识库文章列表<?php echo $category_filter > 0 ? ' - ' . ($category_filter == 1 ? '常见问题' : ($category_filter == 2 ? '教程' : '故障排除')) : ''; ?></h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>标题</th>
                            <th>分类</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($knowledge_articles)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无知识库文章</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($knowledge_articles as $article): ?>
                                <tr>
                                    <td><?php echo $article['id']; ?></td>
                                    <td><?php echo htmlspecialchars($article['title']); ?></td>
                                    <td>
                                        <?php
                                        if ($article['category'] == 1) echo '常见问题';
                                        elseif ($article['category'] == 2) echo '教程';
                                        else echo '故障排除';
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($article['creator_name']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($article['create_time'])); ?></td>
                                    <td>
                                        <a href="knowledge.php?action=edit&id=<?php echo $article['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" style="display: inline;">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="knowledge_id" value="<?php echo $article['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除文章 \'<?php echo htmlspecialchars($article['title']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 使用说明 -->
            <div class="info-box">
                <h3>知识库管理说明</h3>
                <ul>
                    <li>知识库用于存储和管理常见问题解答、使用教程和故障排除指南。</li>
                    <li>您可以添加、编辑和删除知识库文章，以便客服人员和用户查阅。</li>
                    <li>知识库内容分为三类：常见问题、教程和故障排除。</li>
                    <li>常见问题：通常是用户经常咨询的问题及其答案。</li>
                    <li>教程：详细说明系统或产品功能的使用方法。</li>
                    <li>故障排除：帮助解决用户可能遇到的各种问题。</li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>