<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('system_log');

// 记录访问日志
record_log('访问操作日志页面');

// 设置分页参数
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$page_size = 20;
$offset = ($page - 1) * $page_size;

// 设置筛选参数
$username = isset($_GET['username']) ? trim($_GET['username']) : '';
$operation = isset($_GET['operation']) ? trim($_GET['operation']) : '';
$start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : '';
$end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : '';

// 构建查询条件
$conditions = [];
$params = [];

if (!empty($username)) {
    $conditions[] = "username LIKE ?";
    $params[] = "%{$username}%";
}

if (!empty($operation)) {
    $conditions[] = "operation LIKE ?";
    $params[] = "%{$operation}%";
}

if (!empty($start_date)) {
    $conditions[] = "DATE(create_time) >= ?";
    $params[] = $start_date;
}

if (!empty($end_date)) {
    $conditions[] = "DATE(create_time) <= ?";
    $params[] = $end_date;
}

$where_clause = '';
if (!empty($conditions)) {
    $where_clause = " WHERE " . implode(" AND ", $conditions);
}

// 获取总记录数
try {
    $count_sql = "SELECT COUNT(*) as total FROM sys_logs" . $where_clause;
    $stmt = $pdo->prepare($count_sql);
    $stmt->execute($params);
    $total = $stmt->fetch()['total'];
} catch (PDOException $e) {
    $error = '获取日志记录总数失败：' . $e->getMessage();
    $total = 0;
}

// 计算总页数
$total_pages = ceil($total / $page_size);
$page = max(1, min($page, $total_pages));

// 获取日志记录
try {
    $sql = "SELECT * FROM sys_logs" . $where_clause . " ORDER BY id DESC LIMIT " . intval($offset) . ", " . intval($page_size);
    $stmt = $pdo->prepare($sql);

    // 只传递WHERE条件的参数
    $stmt->execute($params);
    $logs = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取日志记录失败：' . $e->getMessage();
    $logs = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>操作日志</h2>
            <div class="breadcrumb">
                <a href="index.php">系统设置</a> &gt; 操作日志
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="username">操作用户：</label>
                            <input type="text" id="username" name="username" value="<?php echo htmlspecialchars($username); ?>">
                        </div>

                        <div class="filter-item">
                            <label for="operation">操作内容：</label>
                            <input type="text" id="operation" name="operation" value="<?php echo htmlspecialchars($operation); ?>">
                        </div>

                        <div class="filter-item">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                        </div>

                        <div class="filter-item">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="log.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 日志记录列表 -->
            <div class="table-responsive">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>用户</th>
                            <th>操作内容</th>
                            <th>IP地址</th>
                            <th>操作时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($logs)): ?>
                            <tr>
                                <td colspan="5" class="text-center">没有找到匹配的日志记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($logs as $log): ?>
                                <tr>
                                    <td><?php echo $log['id']; ?></td>
                                    <td><?php echo htmlspecialchars($log['username'] ?: '未知用户'); ?></td>
                                    <td><?php echo htmlspecialchars($log['operation']); ?></td>
                                    <td><?php echo htmlspecialchars($log['ip']); ?></td>
                                    <td><?php echo $log['create_time']; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分页 -->
            <?php if ($total_pages > 1): ?>
                <div class="pagination">
                    <?php if ($page > 1): ?>
                        <a href="?page=1<?php echo !empty($username) ? '&username=' . urlencode($username) : ''; ?><?php echo !empty($operation) ? '&operation=' . urlencode($operation) : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">首页</a>
                        <a href="?page=<?php echo $page - 1; ?><?php echo !empty($username) ? '&username=' . urlencode($username) : ''; ?><?php echo !empty($operation) ? '&operation=' . urlencode($operation) : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">上一页</a>
                    <?php endif; ?>

                    <?php
                    $start = max(1, $page - 2);
                    $end = min($total_pages, $page + 2);

                    for ($i = $start; $i <= $end; $i++):
                    ?>
                        <?php if ($i == $page): ?>
                            <span class="page-link current"><?php echo $i; ?></span>
                        <?php else: ?>
                            <a href="?page=<?php echo $i; ?><?php echo !empty($username) ? '&username=' . urlencode($username) : ''; ?><?php echo !empty($operation) ? '&operation=' . urlencode($operation) : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link"><?php echo $i; ?></a>
                        <?php endif; ?>
                    <?php endfor; ?>

                    <?php if ($page < $total_pages): ?>
                        <a href="?page=<?php echo $page + 1; ?><?php echo !empty($username) ? '&username=' . urlencode($username) : ''; ?><?php echo !empty($operation) ? '&operation=' . urlencode($operation) : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">下一页</a>
                        <a href="?page=<?php echo $total_pages; ?><?php echo !empty($username) ? '&username=' . urlencode($username) : ''; ?><?php echo !empty($operation) ? '&operation=' . urlencode($operation) : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">末页</a>
                    <?php endif; ?>
                </div>

                <div class="pagination-info">
                    共 <?php echo $total; ?> 条记录，当前 <?php echo $page; ?>/<?php echo $total_pages; ?> 页
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>